#
# spec file for package openstack-ironic-doc
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define component ironic

%define version_unconverted 10.0.1.dev2

Name:           openstack-%{component}-doc
Version:        10.0.1~dev2
Release:        1.1
Summary:        OpenStack Ironic - Documentation
License:        Apache-2.0
Group:          Documentation/HTML
Url:            https://launchpad.net/ironic
Source:         http://tarballs.openstack.org/ironic/ironic-master.tar.gz
BuildRequires:  graphviz
BuildRequires:  openstack-%{component}-test
BuildRequires:  openstack-suse-macros
BuildRequires:  python-%{component}
BuildRequires:  python-Sphinx
BuildRequires:  python-ironic
BuildRequires:  python-openstackdocstheme
BuildRequires:  python-sphinxcontrib-seqdiag
BuildArch:      noarch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Ironic is an Incubated OpenStack project which aims to provision bare metal
machines instead of virtual machines, forked from the Nova Baremetal driver.
It is best thought of as a bare metal hypervisor API and a set of plugins
which interact with the bare metal hypervisors. By default, it will use
PXE and IPMI in concert to provision and turn on/off machines, but Ironic
also supports vendor-specific plugins which may implement additional functionality.

This package contains documentation files for openstack-ironic.

%prep
%setup -q -n %{component}-%{version_unconverted}
%openstack_cleanup_prep
sed -i 's/^warning-is-error.*/warning-is-error = 0/g' setup.cfg

%build
python setup.py build_sphinx
rm doc/build/html/.buildinfo # Remove unneeded files

%install

%files
%defattr(-,root,root,-)
%doc LICENSE doc/build/html

%changelog
* Wed Jan 17 2018 cloud-devel@suse.de
- Update to version ironic-10.0.1.dev2:
  10.0.0
  * Join nodes with traits
  * Introduce hpOneView and ilorest to OneView
* Tue Jan 16 2018 tbechtold@suse.com
- Update to version ironic-9.2.1.dev143:
  * Make the Python 3 job voting
  * Setup ansible interface in devstack
  * Update links
  * Node traits: Add DB API & model
  * Add release 10.0 to release mappings
  * Remove ironic\_tempest\_plugin/ directory
  * Do not validate root partition size for whole disk images in iscsi deploy
  * Switch non-vendor parts admin guide to hardware types
  * Clean up release notes before a release
  * Remove ironic\_tempest\_plugin/ directory
  * Fix initialization of auth token AuthProtocol
  * Add a provisioning target:adopt
  * Devstack: install qemu-system-x86 on RHEL
  * Add uWSGI support
  * Fix ironic node create cli
  * zuul: Update TLSPROXY based on branch
  * Run in superconductor cellsv2 mode for non-grenade jobs
  * Updated from global requirements
  * Add documentation covering storage multi-attach
  * Adds rescue\_interface to base driver class
  * Document the check done in "ironic-dbsync upgrade"
  * zuul: Add ability to specify a 'branch\_override' value
  * zuul: Remove some redundancy by consolidating the 'post.yaml' files
  * Use openstack port create instead of neutron port-create
  * ansible: handle mount of /sys the same way IPA does it
  * [ansible] add defaults to config
  * Prevent changes to the ironic\_tempest\_plugin/ directory
  * Finalize migration to keystoneauth adapters
  * Updated from global requirements
  * Follow up Add additional capabilities discovery for iRMC driver
  * Use NamedExtensionManager for drivers
  * Use the tempest plugin from openstack/ironic-tempest-plugin
  * Switch emphasis to hardware types in the installation guide
  * Use adapters for neutronclient
  * Remove deprecated ironic.common.policy.enforce()
  * Auto-detect the defaults for [glance]swift\_{account,temp\_url\_key,endpoint\_url}
  * Add 'nova hypervisor-list' in example set of commands to compare the resources in Compute service and Bare Metal service
  * Receive and store agent version on heartbeat
  * tox: Use the default version of Python 3 for tox tests
  * Remove unused methond \_get\_connect\_string
  * Update comment on location of webapi-version-history.rst
  * Updated from global requirements
  * Do not access dbapi attributes on dbsync import
  * Fix swiftclient creation
  * Update docs to include API version pinning
  * Add networking-fujitsu ML2 driver to multitenacy doc
  * Updated from global requirements
  * 9.2.0 is the ironic version with rebuild configdrive
  * Pin API version during rolling upgrade
  * devstack to \`git pull sushy-tools\` if required
  * Add spec & priorities links to contributor doc
  * Fix HPE headers for oneview
  * Updated from global requirements
  * Fix the format command-line
  * Add information about neutron ML2 drivers to multitenancy docs
  * Apply pep8 check to app.wsgi
  * ironic.conf.sample includes default\_resource\_class
  * Add a configuration option for the default resource class
  * Rework drivers page in the admin documentation
  * Update bindep.txt for doc builds
  * Don't collect logs from powered off nodes
  * Add additional capabilities discovery for iRMC driver
  * Use adapters for inspectorclient
  * Use adapters for cinderclient
  * Imported Translations from Zanata
  * Followup to I07fb8115d254e877d8781207eaec203e3fdf8ad6
  * Add missing gzip call to FAQ item on how to repack IPA
  * Rework keystone auth for glance
  * Remove setting of version/release from releasenotes
  * zuul.d: Remove unneeded required-projects
  * Updated from global requirements
  * Add 9.2 to release mappings
  * Remove provisioning network ports during tear down
  * Fix image type for partition-pxe\_ipmitool-tinyipa-python3 job
  9.2.0
  * update description for Change Node Power State
  * Add no-vendor interface to the idrac hardware types
  * Updated from global requirements
  * Fail deploy if agent returns >= 400
  * Don't run multinode jobs for changes to driver-requirements.txt
  * Revert "Introduce hpOneView and ilorest to OneView"
  * Revert "Migrate oneview driver to use python-hpOneView"
  * Revert "Fix persistent information when getting boot device"
  * Revert "Add a timeout for powering on/off a node on HPE OneView Driver"
  * Revert "Migrate python-oneviewclient validations to Ironic OneView drivers"
  * Revert "Remove python-oneviewclient from Ironic OneView drivers"
  * Revert "Get a new OneView client when needed"
  * Revert "Update python-ilorest-library to hardware type OneView"
  * Add missing 'autospec' to unit tests - /unit/objects/
  * Add ansible deploy interface
  * Clean up release notes from the upcoming release
  * Fix misplaced reno note
  * Make the api format correctly
  * [devstack] stop setting or relying on standard properties
  * Remove some deprecated glance options
  * zuul.d/projects.yaml: Sort the job list
  * project.yaml: Remove 'branches:' & jobs that don't run on master
  * Miss node\_id in devstack lib
  * Update idrac hardware type documentation
  * Update Zuul 'gate' job
  * Rolling upgrades related dev documentation
  * Update python-ilorest-library to hardware type OneView
  * Add rescue\_interface to node DB table
  * Get a new OneView client when needed
  * Run tempest jobs when update requirements
  * Updated from global requirements
  * Remove unused IronicObjectIndirectionAPI from ironic-api
  * Add release note for fix to port 0 being valid
  * Simplify the logic of validate\_network\_port
  * Follow up Secure boot support for irmc-virtual-media driver
  * devstack: Clean up some of the devstack code
  * Remove python-oneviewclient from Ironic OneView drivers
  * Allow to set default ifaces in DevStack
  * Reword interface information in multitenancy docs
  * Ensure ping actually succed
  * Fix minor documentation missing dependency
  * Small fixes in the common reference architecture docs
  * [reno] Update ironic-dbsync's check object version
  * Migrate python-oneviewclient validations to Ironic OneView drivers
  * Remove unnesessary description for config parameters in cinder group
  * Update ironic.sample.conf
  * Fix the format issues of User guide
  * Zuul: add file extension to playbook path
  * Add I202 to flake ignore list
  * Revise deploy process documentation
  * Add a timeout for powering on/off a node on HPE OneView Driver
  * ironic-dbsync: check object versions
  * Update validating node information docs
  * Use jinja rendering from utils module
  * Add ability to provide configdrive when rebuilding
  * Finish the guide on upgrading to hardware types
  * Move ironic legacy jobs into the ironic tree
  * Fix missing logging format error
  * Add missing 'autospec' to unit tests - /unit/common/
  * [bfv] Set the correct iqn for pxe
  * Fix "import xx as xx" grammer
  * Secure boot support for irmc-virtual-media driver
  * Change pxe dhcp options name to codes
  * Updated from global requirements
  * [docs] describe vendor passthru in hw types
  * Add bindep.txt file
  * Fix some mis-formatted log messages in oneview driver
  * Disallow rolling upgrade from Ocata to Queens
  * Add online data migrations for conductor version
  * [Devstack] Replace tap with veth
  * Support SUM based firmware update as clean step for iLO drivers
  * Add missing 'autospec' to unit tests - /unit/dhcp/
  * Update tests to do not use deprecated test.services()
  * Makes ironic build reproducible
  * Remove 'next' for GET /nodes?limit=1&instance\_uuid=
  * ListType preserves the order of the input
  * Add default configuration files to data\_files
  * Use DocumentedRuleDefault instead of RuleDefault
  * Reference architecture: common bits
  * Fixes a small documentation typo in snmp
* Mon Oct  9 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev210:
  * ipmitool: reboot: Don't power off node if already off
  * Reduce complexity of node\_power\_action() function
* Sat Oct  7 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev206:
  * Fix mis-formatted log messages
  * Follow-up patch 'Cleanup unit tests for ipmittool'
  * Update after recent removal of cred manager aliases
* Fri Oct  6 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev200:
  * Use oslotest for base test case
  * Stop passing raw Exceptions as the reasons for ironic Image exceptions
* Thu Sep 28 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev197:
  * Documentation for 'oneview' hardware type
  * Cleanup unit tests for ipmittool
  * Add documentation describing each Ironic state
* Tue Sep 26 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev191:
  * main page: add links to docs on Upgrade to HW Types
  * Cleanup test-requirements
  * Fix API VIF tests when using flat network
  * Updated from global requirements
  * Migrate to stestr as unit tests runner
  * [reno] update for MAC address update fix
* Fri Sep 22 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev181:
  * Revert "Change pxe dhcp options name to codes."
  * Drop neutron masking exception in vif\_attach
  * Rework update\_port\_address logic
  * api-ref portgroup\_id should be portgroup\_ident
  * Document setting discover\_hosts\_in\_cells\_interval in nova.conf
  * Adds more exception handling for ironic-conductor heartbeat
  * Updated from global requirements
* Sat Sep 16 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev167:
  * Change pxe dhcp options name to codes
* Fri Sep 15 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev165:
  * Updated from global requirements
* Thu Sep 14 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev164:
  * Updated from global requirements
  * Stop using Q\_PLUGIN\_EXTRA\_CONF\_{PATH|FILES} variables
  * Update vif\_attach from NeutronVIFPortIDMixin
* Sun Sep 10 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev160:
  * Put unit test file in correct directory
* Sat Sep  9 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev158:
  * Replace http with https for doc links
  * flake8: Enable some off-by-default checks
  * Update upgrade guide to use new pike release
  * [install docs] ironic -> openstack baremetal CLI
  * Fix persistent information when getting boot device
  * Migrate oneview driver to use python-hpOneView
  * Fix a typo
* Fri Sep  8 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev145:
  * Using devstack configure\_rootwrap to configure ironic rootwrap
  * Use newer location for iso8601 UTC
  * reformat REST API Version History page
  * [doc] Non-word updates to releasing doc
  * Fix race condition in backfill\_version\_column()
* Thu Sep  7 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev135:
  * [reno] Clarify fix for missing boot.prepare\_instance
  * Introduce hpOneView and ilorest to OneView
  * Replace DbMigrationError with DBMigrationError
  * [reno] Clarify fix for BFV & image\_source
  * Build docs with Python 2 for now
* Wed Sep  6 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev125:
  * Switch API ref to use versionadded syntax throughout
  * Fix unit test for new fields in invaid API version
  * Put tests in correct location for ironic/api/controllers/v1/
  * Troubleshooting docs: explain disabled compute services
  * Update documentation for \`\`ilo\`\` hardware type
  * [docs] Update Releasing Ironic Projects
  * tox.ini: Add 'py36' to the default envlist
  * Introduce keystoneauth adapters for clients
* Tue Sep  5 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev110:
  * Updated from global requirements
* Mon Sep  4 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev108:
  * [contributor docs] ironic -> OSC baremetal CLI
* Sun Sep  3 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev106:
  * Boot from volume fails with 'iscsi' deploy interface
* Fri Sep  1 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev105:
  * Boot from volume fails with 'iscsi' deploy interface
  * Minor improvements to the resource classes documentation
  * Update Nova configuration documentation
  * [doc] add FAQ about updating release notes
  * Follow-up for commit cb793d013610e6905f58c823e68580714991e2df
  * Follow up Secure boot support for irmc-pxe driver
* Thu Aug 31 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev94:
  * Add doc/source/\_static to .gitignore
* Wed Aug 30 2017 cloud-devel@suse.de
- Update to version ironic-9.1.0.dev92:
  * Fix indentation in few of the documentation pages
  * Upgrade guide for \`snmp\` hardware type
  * devstack: Comment variables related to multi-tenant networking
  * Test ironic-dbsync online\_data\_migrations
  * Add a comment about default devstack images
  * Fix to use "." to source script files
  * Add Sem-Ver flag to increment master branch version
  * conductor saves version in db
  * Put tests in correct location for ironic/api/controllers/v1/
* Mon Aug 28 2017 cloud-devel@suse.de
- Update to version ironic-9.0.1.dev75:
  * remove REST API examples from RAID doc
* Mon Aug 28 2017 cloud-devel@suse.de
- Update to version ironic-9.0.1.dev73:
  * Add #!/bin/bash to devstack/common\_settings
  * [admin docs] ironic -> openstack baremetal CLI
* Sat Aug 26 2017 cloud-devel@suse.de
- Update to version ironic-9.0.1.dev70:
  * Update Pike release title to include version range
  * Updated from global requirements
* Fri Aug 25 2017 cloud-devel@suse.de
- Update to version ironic-9.0.1.dev67:
  * [doc] change absolute to relative URL
* Thu Aug 24 2017 cloud-devel@suse.de
- Update to version ironic-9.0.1.dev66:
  * Configuration documentation migrated
  * fix a typo in agent.py: s/doman/domain/
  * Documentation for irmc hardware type
  * correct URLs in contributor docs & main index
  * Correct URLs in install docs
  * correct URLs in admin docs
  * Set explicit default to enabled driver interfaces
* Wed Aug 23 2017 tbechtold@suse.com
- Fix doc build
* Wed Aug 23 2017 cloud-devel@suse.de
- Update to version ironic-9.0.1.dev52:
  * Documentation for 'snmp' hardware type
  * Fix incorrect documentation urls
  * Updated from global requirements
  * Partially revert "Set resource class during upgrade"
  * [doc] Replace http with https
  * Follow-up to \`\`ilo\`\` hardware type documentation
* Tue Aug 22 2017 cloud-devel@suse.de
- Update to version ironic-9.0.1.dev40:
  * Set resource class during upgrade
  * Fix names of capabilities for FibreChannel volume boot
  * iRMC: Follow-up: volume boot for virtual media boot interface
  * Add 9.1 to release\_mappings
  * Add 'force\_persistent\_boot\_device' to pxe props
  * devstack: Remove unused variable IRONIC\_VM\_NETWORK\_RANGE
  * Add the new capabilities to the iLO InspectInterface
* Mon Aug 21 2017 cloud-devel@suse.de
- Update to version ironic-9.0.1.dev27:
  * Imported Translations from Zanata
* Sun Aug 20 2017 cloud-devel@suse.de
- Update to version ironic-9.0.1.dev25:
  * Do not restart n-cpu during upgrade
  * Make SNMP UDP transport settings configurable
  * Enable OSProfiler support in Ironic - follow-up
  * Wait for cleaning is completed after base smoke tests
  * Add 'hardware type' for Dell EMC iDRACs
  * Fix DRAC classic driver double manage/provide
  * [devstack] use resource classes by default
  * Add functional API tests for volume connector and volume target
  * Update proliantutils version for Pike release
* Sat Aug 19 2017 cloud-devel@suse.de
- Update to version ironic-9.0.1.dev9:
  * Get rid of sourcing stackrc in grenade settings
  * Update reno for stable/pike
* Fri Aug 18 2017 cloud-devel@suse.de
- Update to version ironic-9.0.1.dev5:
  * Adds 9.0 to release\_mappings
  * Revert "[reno] Add prelude for Pike release"
  9.0.0
  * [docs] update irmc boot-from-volume
  * [releasenotes] update irmc's boot-from-volume support
  * [reno] Add prelude for Pike release
* Thu Aug 17 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev527:
  * Add storage interface to enabling-drivers doc
  * Add admin guide for boot from volume
  * iRMC: Add documentation for remote volume boot
  * Remove ensure\_logs\_exist check during upgrade
  * [reno] update
* Wed Aug 16 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev517:
  * Follow-up to rolling upgrade docs
  * Documetation for 'ilo' hardware type
  * Update the documentation links - code comments
  * Update the documentation links - install guide
  * Remove translator assignments from i18n
  * Add hardware types to support Cisco UCS Servers
  * iRMC: Support volume boot for iRMC virtual media boot interface
* Tue Aug 15 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev503:
  * Remove setting custom http\_timeout in grenade
  * Upgrade to hardware types: document changing interfaces for active nodes
  * Update the resource classes documentation based on recent progress
  * Rolling upgrade procedure documentation
* Sun Aug 13 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev495:
  * [devstack] switch to the latest API version and OSC commands
  * Doc for disk erase support in iLO drivers
* Sat Aug 12 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev491:
  * Prevent changes of a resource class for an active node
  * Guide on upgrading to hardware types
  * Adds hardware type for SNMP powered systems
  * Add tempest plugin API tests for driver
* Fri Aug 11 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev484:
  * Release notes clean up for the next release
  * Secure boot support for irmc-pxe driver
  * Add a flag to always perform persistent boot on PXE interface
* Thu Aug 10 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev478:
  * Fix missing print format error
* Tue Aug  8 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev477:
  * Add a guide for Devstack configuration for boot-from-volume
  * Remove future plan from portgroup document
* Sat Aug  5 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev474:
  * [tempest] also catch BadRequest in negative tests with physical\_network in old API
  * Use more specific asserts in tests
  * BFV Deploy skip minor logging, logic, and test fixes
  * Trigger interface attach tests
  * Prevent tests from using utils.execute()
* Fri Aug  4 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev464:
  * [Trivialfix]Fix typos in ironic
  * Remove WARNING from pin\_release\_version's help
  * Update ironic.conf.sample due to non-ironic code
  * Add new dbsync command with first online data migration
  * Add hardware type for HPE OneView
  * Removed unnecessary setUp() call in unit tests
  * Remove SSH-based driver interfaces and drivers
  * [devstack] add support for running behind tls-proxy
  * Revert "Wait until iDRAC is ready before out-of-band cleaning"
  * Avoid double ".img" postfix of image file path in devstack installation
* Thu Aug  3 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev444:
  * [doc-migration] Add configuration folder for documentation
  * Add storage interface to api-ref
  * Add API for volume resources to api-ref
  * Disable automated cleaning for single node grenade
  * Optimize node locking on heartbeat
  * Remove file RELEASE-NOTES
  * Adds doc for restore\_irmc\_bios\_config clean step
  * [Tempest] fix negative tests on old API versions
  * Remove install-guide env which is no longer effective
  * Refactor VIFPortIDMixin: factor out common methods
  * Enable OSProfiler support in Ironic
* Wed Aug  2 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev422:
  * Change ramdisk log filename template
  * Add negative attribute to negative port tests
* Tue Aug  1 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev418:
  * Address review feedback for ipxe boot file fix
  * Remove usage of some of the deprecated methods
  * Updated from global requirements
  * Tempest scenario test for boot-from-volume
  * Rolling upgrades support for create\_port RPCAPI
  * Changes log level of a message
  * Refactor get\_physnets\_by\_portgroup\_id
* Mon Jul 31 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev404:
  * Added a condition for 'ilo' hardware type
* Sun Jul 30 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev402:
  * grenade: Use test\_with\_retry to check if route is up
  * Removes agent mixin from oneview drivers
  * Rolling upgrades support for port.physical\_network
* Sat Jul 29 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev397:
  * Don't use multicell setup for ironic & increase timeout
* Fri Jul 28 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev395:
  * [doc] update ironic's landing page
* Thu Jul 27 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev393:
  * Fixes hashing issues for py3.5
  * Generate iPXE boot script on start up
  * grenade: For multi-node grenade, do not upgrade nova
  * Fix small issues in the installation documentation
  * Update comments related to ipmi & old BMCs
* Wed Jul 26 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev385:
  * Fix docstring and default value for local\_group\_info
  * Add tempest tests for physical networks
  * Update URL home-page in documents according to document migration
* Tue Jul 25 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev379:
  * Adding note for ironic virt driver nova-compute changes
  * py3.5:Workaround fix for forcing virtualbmc installation with pip2
  * Start passing portgroup information to Neutron
  * Updated from global requirements
  * Refactor VIFPortIDMixin: rename
  * DevStack: Add configuration for boot-from-volume
  * Allow updating interfaces on a node in available state
* Sat Jul 22 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev365:
  * Updated from global requirements
  * Improve ports API reference
  * Replace the usage of 'manager' with 'os\_primary'
* Fri Jul 21 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev360:
  * replace 'interrace' with 'interface'
  * Improve port update API unit tests
* Thu Jul 20 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev357:
  * Expose ports' physical network attribute in API
  * Rename 'remove\_unavail\_fields' parameter
* Wed Jul 19 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev353:
  * Add missing parameter descriptions
  * Updated from global requirements
  * Modifications for rolling upgrades
  * Improve graceful shutdown of conductor process
  * remove explicit directions for release notes on current branch
* Sun Jul 16 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev344:
  * Follow-up to fix for power action failure
* Sat Jul 15 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev342:
  * Updated from global requirements
  * Generate iPXE boot script when deploying with boot from volume
  * Add Driver API change in 1.33 to history
  * Using non-persistent boot in PXE interface
* Fri Jul 14 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev335:
  * Fix copy/paste error in VIF attach note
  * Force InnoDB engine on interfaces table
* Wed Jul 12 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev332:
  * [reno] Clarify fix for inspect validation failures
  * [trivial] Fix argument descriptions
  * Fix broken links in tempest plugin README
  * Add storage interface field to node-related notifications
  * Enable cinder storage interface for generic hardware
  * Set nomulticell flag for starting nova-compute in grenade
  * Physical network aware VIF attachment
* Tue Jul 11 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev318:
  * Remove \_ssh drivers from dev-quickstart
* Mon Jul 10 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev317:
  * Raise HTTP 400 rather than 500 error
* Sun Jul  9 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev315:
  * Make IP address of socat console configurable
* Sat Jul  8 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev313:
  * Removed nonexistent option from quickstart snippet
  * Mock random generator for BackoffLoopingCall in IPMI unittests
  * Update README to point at new doc location
  * Move ironic dbsync tool docs into doc/source/cli
* Fri Jul  7 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev309:
  * Move doc/source/dev to doc/source/contributor
  * Move operator docs into into doc/source/admin
* Thu Jul  6 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev307:
  * Move install guide into new doc/source/install location
* Wed Jul  5 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev306:
  * switch from oslosphinx to openstackdocstheme
  * Add REST API for volume connector and volume target operation
* Tue Jul  4 2017 cloud-devel@suse.de
- Update to version ironic-8.0.1.dev302:
  * Fix quotes in documentation and schema description
  * Follow-up for bugfix 1694645 patch
  * Add node power state validation to volume resource update/deletion
  * Adds clean step 'restore\_irmc\_bios\_config' to iRMC drivers
  * Add ldlinux.c32 to boot ISO for virtual media
* Mon Jul  3 2017 tbechtold@suse.com
- Update to version ironic-8.0.1.dev292:
  * Make redfish power interface wait for the power state change
  * Refactor common keystone methods
  * Add CRUD notification objects for volume connector and volume target
  * Updated from global requirements
  * Don't retry power status if power action fails
  * Fix VIF list for noop network interface
  * Fetch Glance endpoint from Keystone if it's not provided in the configuration
  * Logic for skipping deployment with BFV
  * iPXE template support for iSCSI
  * Move \_abort\_attach\_volumes functionality to detach\_volumes
  * Allow to load a subset of object fields from DB
  * Unit test consistency: DB base and utils prefix
  * Updated from global requirements
  * Updated from global requirements
  * Remove unnecessary line in docstring
  * Validate portgroup physical network consistency
  * Wire in storage interface attach/detach operations
  * Wait until iDRAC is ready before out-of-band cleaning
  * Minor changes to object version-related code
  * Remove times.dbm prior to test run
  * Discover hosts while waiting for hypervisors to show up in devstack
  * Add docs for node.resource\_class and flavor creation
  * Updated from global requirements
  * Move port object creation to conductor
  * Make default\_boot\_option configurable in devstack
  * Follow-up docstring revision
  * Runs the script configure\_vm.py in py3.5
  * Replace get\_transport with get\_rpc\_transport
  * Add version column
  * Remove legacy auth loading
  * Add a note for specifying octal value of permission
  * Improve driver\_info/redfish\_verify\_ca value validation
  * Updated from global requirements
  * Stop sending custom context values over RPC
  * Replace assertTrue(isinstance()) with assertIsInstance()
  * Change volume metadata not to use nested dicts
  * Add physical network to port data model
  * Move deploy\_utils warnings to conductor start
  * Remove unused methods from GlanceImageService
  * [install-guide] explain the defaults calculation for hardware types
  * Improve driver\_info/redfish\_system\_id value validation
  * Add guru meditation report support
  * Adds parameters to run CI with hardware types
  * Fix description for [cinder] action\_retries option
  * Deprecate elilo support
  * Updated from global requirements
  * Update ipmitool installation and usage documentation
  * Replace test.attr with decorators.attr
  * Updated from global requirements
  * Replace test.attr with decorators.attr
  * Use cfg.URIOpt for URLs with required schemes
  * Updated from global requirements
  * Remove unneeded lookup policy check
  * Add Cinder storage driver
  * Add ipmitool vendor interface to the ipmi hardware type
  * Replace test.attr with decorators.attr
  * Fix directories permission for tftpboot
  * Comment the default values in policy.json.sample
  * Replace deprecated .assertRaisesRegexp()
  * Updated from global requirements
  * Remove remaining vendor passthru lookup/heartbeat
  * Remove unit tests that test oslo\_concurrency.processutils.execute
  * Remove single quoted strings in json sample
  * Refactor install-guide: update node enrollment
  * Refactor install-guide: driver and hardware types configuration
  * Minor clean up in iLO drivers unit tests
  * Remove translation of log messages
  * Enable getting volume targets by their volume\_id
  * Check if sort key is allowed in API version
  * Updated from global requirements
  * Remove logging translation calls from ironic.common
  * [install-guide] add section on Glance+Swift config
  * Fix attribute name of cinder volume
  * Update reno for new ilo hardware type
  * Remove log translations from ironic/drivers Part-1
  * Update developer quickstart doc about required OS version
  * Add 'iscsi' deploy support for 'ilo' hardware type
  * Trivial fix typos while reading doc
  * Fix docstrings in conductor manager
  * [devstack] start virtualpdu using full path
  * [Devstack] Increase default NIC numbers for VMs to 2
  * Remove usage of parameter enforce\_type
  * Properly allow Ironic headers in REST API
  * Updated from global requirements
  * DevStack: Install gunicorn and sushy based on g-r constraints
  * Fix keystone.py 'get\_service\_url' method parameter
  * Add functional api tests for node resource class
  * Refactor install-guide: integration with other services
  * Remove references to EOLed version of Ironic from the install guide
  * DevStack: Setup a Redfish environment
  * Add hardware type for HPE ProLiant servers based on iLO 4
  * Bring the redfish driver address parameter closer to one of other drivers
  * [Grenade]: Do not run ir-api on primary node after upgrade
  * Validate outlet index in SNMP driver
  * [Devstack] Rework VMs connection logic
  * Fix oslo.messaging log level
  * Add context to IronicObject.\_from\_db\_object()
  * Add release notes for 8.0.0
  * [api-ref] remove reference to old lookup/heartbeat
  * Follow-up patch to redfish documentation
  * [devstack] use the generic function to setup logging
  * Fix cleaning documents
  * Remove obsolete sentence from comment
  * TrivialFix: Remove logging import unused
  * Remove translation of log messages from ironic/drivers/modules/irmc
  * Run db\_sync after upgrade
  * Remove translation of log messages from ironic/drivers/modules/ucs
  * Start enforcing config variables type in tests
  * Add documentation for the redfish driver
  * Read disk identifier after config drive setup
  * Add a paragraph about image validation to Install Guide
  * Make terminal timeout value configurable
  * Remove nova mocks from documentation configuration
  * Remove fake\_ipmitool\_socat driver from the documentation
  * Add redfish driver
  * Ensure we install latest libivrt
  * Set env variables when all needed files are source
  * save\_and\_reraise\_exception() instead of raise
  * Follow-up patch of 7f12be1b14e371e269464883cb7dbcb75910e16f
  * VirtualPDU use libvirt group instead of libvirtd
  * Fix unit tests for oslo.config 4.0
  * Always set host\_id when adding neutron ports
  * Add /baremetal path instead of port 6385
  * Add SUSE instructions to the install guide
  * Remove pre-allocation model for OneView drivers
  * Remove log translations from iLO drivers
  * Follow-up patch of 565b31424ef4e1441cae022486fa6334a2811d21
  * Setup logging in unit tests
  * Remove deprecated DHCP provider methods
  * Make config generator aware of 'default\_log\_levels' override
  * [Devstack] Fix libvirt group usage
  * Common cinder interface additional improvements
  * Config drive support for ceph radosgw
  * Improve error message for deleting node from error state
  * Updated from global requirements
  * Add comments re RPC versions being in sync
  * Help a user to enable console redirection
  * Fix some reST field lists in docstrings
  * add portgroups in the task\_manager docstrings
  * Remove unneeded exception handling from agent driver
  * Updated from global requirements
  * Remove translation of log messages from ironic/dhcp and ironic/cmd
  * Updated from global requirements
  * Bypassing upload deploy ramdisk/kernel to glance when deploy iso is given
  * Drop commented import
  * Enforce releasenotes file naming
  * Remove unused methods in common/paths and common/rpc
  * Remove translation of log messages from ironic/api
  * Fix access to CONF in dhcp\_options\_for\_instance
  * Add string comparison for 'IRONIC\_DEPLOY\_DRIVER'
  * Modify the spelling mistakes Change explictly to explicitly
  8.0.0
  * Revert "[Devstack] Rework VMs connection logic"
  * Fix base object serialization checks
  * Node should reflect what was saved
  * Changes 'deploy' and 'boot' interface for 'pxe\_ilo' driver
  * Use standard deploy interfaces for iscsi\_ilo and agent\_ilo
  * Refactor iLO drivers code to clean 'boot' and 'deploy' operations
  * Updated from global requirements
  * Add base cinder common interface
  * Updates to RPC and object version pinning
  * Add release note for messaging alias removal
  * Remove deprecated method build\_instance\_info\_for\_deploy()
  * Remove deprecated, untested ipminative driver
  * [Devstack] Rework VMs connection logic
  * Add assertion of name to test\_list\_portgroups test
  * Remove deprecated [ilo]/clean\_priority\_erase\_devices config
  * Convert BaseDriver.\*\_interfaces to tuples
  * [Devstack] cleanup upgrade settings
  * Call clean\_up\_instance() during node teardown for Agent deploy
  * Don't pass sqlite\_db in db\_options.set\_defaults()
  * Fix some api field lists in docstrings
  * Fix file\_has\_content function for Py3
  * Speed up test\_touch\_conductor\_deadlock()
  * grenade: Only 'enable\_plugin ironic' if not already in conf
  * Remove overwriting the default value of db\_max\_retries
  * devstack: Make sentry \_IRONIC\_DEVSTACK\_LIB a global variable
  * Fix missing \_ import in driver\_factory
  * Fix BaseBaremetalTest.\_assertExpected docstring
  * Deduplicate \_assertExpected method in tests
  * Fix missed '\_' import
  * Change misc to test\_utils for tempest test
  * Switch to use test\_utils.call\_until\_true
  * exception from driver\_factory.default\_interface()
  * Remove trailing slash from base\_url in tempest plugin
  * Improve enabled\_\*\_interfaces config help and validation
  * Make \_send\_sensors\_data concurrent
  * [devstack] remove deprecated IRONIC\_IPMIINFO\_FILE
  * Do not change admin\_state for tenant port
  * Remove deprecated [deploy]erase\_devices\_iterations
  * Duplicated code in ..api.get\_active\_driver\_dict()
  * [Devstack] Set DEFAULT\_IMAGE\_NAME variable
  * Don't override device\_owner for tenant network ports
  * Switch to decorators.idempotent\_id
  * [Devstack] enable only pxe|agent\_ipmitool by default
  * Clean up driver\_factory.enabled\_supported\_interfaces
  * make sure OVS\_PHYSICAL\_BRIDGE is up before bring up vlan interface
* Fri Mar 31 2017 cloud-devel@suse.de
- Update to version ironic-7.0.1.dev170:
  * Docs: bump tempest microversion caps after branching
  * Skip PortNotFound when unbinding port
  * Remove unnecessary setUp function in testcase
  * Remove extra blank space in ClientSide error msg
  * Convert BaseDriver.*_interfaces to tuples
  * Skip VIF tests for standalone ironic
* Thu Mar 30 2017 cloud-devel@suse.de
- Update to version ironic-7.0.1.dev158:
  * Updated from global requirements
  * [doc] Update examples in devstack section
  * devstack: install python-dracclient if DRAC enabled
  * Don't pass sqlite_db in db_options.set_defaults()
  * Copy and append to static lists
  * Define minimum required API ver for portgroups
  * Add RPC and object version pinning
  * Updated from global requirements
  * Fix docstrings for creating methods in baremetal api tests
  * Extend tests and checks for node VIFs
  * Remove translation of log messages from ironic/conductor
  * Add functional API tests for portgroups
  * Revert the move of the logger setup
  * [devstack] Use global requirements for virtualbmc
  * Updates documentation to install PySqlite3
  * Remove log translation function calls from ironic.db
  * Fix local copy of scenario manager
  * Add standalone tests using direct HTTP links
  * devstack: When Python 3 enabled, use Python 3
  * Remove old oslo.messaging transport aliases
  * Fix file_has_content function for Py3
  * Fix usage of various deprecated methods
  * Prune local copy of tempest.scenario.manager.py
  * devstack: Don't modprobe inside containers
  * Include a copy of tempest.scenario.manager module
  * flake8: Specify 'ironic' as name of app
  * Updated from global requirements
  * Fix API doc URL in GET / response
  * Add ironic standlaone test with ipmi dynamic driver
  * Update new proliantutils version to 2.2.1
  * Add Ironic standalone tests
  * Fix typos of filename in api-ref
  * Updated from global requirements
  * Fix the exception message in tempest plugin
  * Speed up test_touch_conductor_deadlock()
  * Cleanup hung iscsi session
  * Refactor waiters in our tempest plugin
  * Deprecate support for glance v1
  * This adds a tempest test for creating a chassis with a specific UUID
  * Address a shell syntax mistake
  * Update ironic.conf.sample
  * grenade: Only 'enable_plugin ironic' if not already in conf
  * Remove overwriting the default value of db_max_retries
  * Do not load credentials on import in tempest plugin clients.py
  * Update the Ironic Upgrade guide
  * Validation before perform node deallocation
  * Add wsgi handling to ironic-api in devstack
  * Fix updating node.driver to classic
  * devstack: Make sentry _IRONIC_DEVSTACK_LIB a global variable
  * Use Sphinx 1.5 warning-is-error
  * Fixed release note for DBDeadLock handling
  * Remove references to py34 from developer guide
  * Delete release note to fix build
  * Correct typos in doc files
  * Clean up eventlet monkey patch comment and reno
  * Moved fix-socat-command release note
  * Allow to attach/detach VIFs to active ironic nodes
  * Move eventlet monkey patch code
  * Updated from global requirements
  * doc: update FAQ for release notes
  * Update test requirement
  * Updated from global requirements
  * Remove gettext.install() for unit tests
  * Document PXE with Spanning Tree in troubleshooting FAQ
  * Explicitly use python 2 for the unit-with-driver-libs tox target
  * Move heartbeat processing to separate mixin class
* Wed Mar  1 2017 cloud-devel@suse.de
- Update to version ironic-7.0.1.dev35:
  * Fix missing _ import in driver_factory
  * Add support for DBDeadlock handling
  * Fix BaseBaremetalTest._assertExpected docstring
  * Trivial: Change hardcoded values in tempest plugin
  * Add testcases for iLO drivers
  * Add ironic port group CRUD notifications
* Tue Feb 28 2017 cloud-devel@suse.de
- Update to version ironic-7.0.1.dev24:
  * Updated ramdisk API docstrings
  * Developer guide should not include Python 3.4
  * devstack: Adding a README for ironic-bm-logs directory
* Fri Feb 24 2017 cloud-devel@suse.de
- Update to version ironic-7.0.1.dev19:
  * Use flake8-import-order
* Thu Feb 23 2017 cloud-devel@suse.de
- Update to version ironic-7.0.1.dev17:
  * Deduplicate _assertExpected method in tests
  * Switch to new location for oslo.db test cases
* Wed Feb 22 2017 cloud-devel@suse.de
- Update to version ironic-7.0.1.dev13:
  * Remove unused logging import
* Fri Feb 17 2017 cloud-devel@suse.de
- Update to version ironic-7.0.1.dev12:
  * Use specific end version since liberty is EOL
* Thu Feb 16 2017 cloud-devel@suse.de
- Update to version ironic-7.0.1.dev10:
  * Remove logging import unused
  * Fix some PEP8 issues and Openstack Licensing
* Wed Feb 15 2017 cloud-devel@suse.de
- Update to version ironic-7.0.1.dev7:
  * Update release nodes for Ocata
  * reno 'upgrades' should be 'upgrade'
  * Updated from global requirements
  * Update docs create port group
  7.0.0
* Tue Feb 14 2017 cloud-devel@suse.de
- Update to version ironic-6.3.0.dev823:
  * Clean up release notes for 7.0.0
  * Add a summary release note for ocata
  * Walk over all objects when doing VIF detach
  * Change misc to test_utils for tempest test
  * Follow-up iRMC power driver for soft reboot/poff
  * Minor updates to multi-tenancy documentation
* Mon Feb 13 2017 cloud-devel@suse.de
- Update to version ironic-6.3.0.dev811:
  * Fix unit tests with UcsSdk installed
* Sat Feb 11 2017 cloud-devel@suse.de
- Update to version ironic-6.3.0.dev809:
  * Mock client initializations for irmc and oneview
  * Follow up patch for SNMPv3 support
  * Add a tox target for unit tests with driver libraries
  * Fix missed '_' import
  * Update api-ref for dynamic drivers
  * Switch to use test_utils.call_until_true
  * Add port groups configuration documentation
  * Remove most unsupported drivers
  * SNMP agent support for OOB inspection for iLO Drivers
  * No node interface settings for classic drivers
  * Fix object save after refresh failure
  * Adds network check in upgrade phase in devstack
* Fri Feb 10 2017 cloud-devel@suse.de
- Update to version ironic-6.3.0.dev785:
  * Source lib/ironic in grenade settings
* Thu Feb  9 2017 cloud-devel@suse.de
- Update to version ironic-6.3.0.dev783:
  * Unbind tenant ports before rebuild
  * Remove a py34 environment from tox
  * Pass session directly to swiftclient
* Wed Feb  8 2017 cloud-devel@suse.de
- Update to version ironic-6.3.0.dev777:
  * Fix log formating in ironic/common/neutron
  * Use https instead of http for git.openstack.org
  * Validate the network interface before cleaning
  * log if 'flat' interface and no cleaning network
  * exception from driver_factory.default_interface()
  * [devstack] Allow using "ipmi" hardware type
  * Remove trailing slash from base_url in tempest plugin
* Tue Feb  7 2017 cloud-devel@suse.de
- Update to version ironic-6.3.0.dev764:
  * Fix setting persistent boot device does not work
* Sun Feb  5 2017 cloud-devel@suse.de
- Update to version ironic-6.3.0.dev762:
  * Improve enabled_*_interfaces config help and validation
* Sat Feb  4 2017 cloud-devel@suse.de
- Update to version ironic-6.3.0.dev760:
  * Prepare for using standard python tests
  * [Devstack] fix waiting resources on subnode
  * Log an actual error message when failed to load new style credentials
  * Speed up irmc power unit tests
  * Allow duplicate execution of update node DB api method
  * Validate port info before assume we may use it
  * Removes unnecessary utf-8 encoding
* Fri Feb  3 2017 cloud-devel@suse.de
- Update to version ironic-6.3.0.dev746:
  * Add bumping sem-ver to the releasing docs
  * Make _send_sensors_data concurrent
  * [devstack] remove deprecated IRONIC_IPMIINFO_FILE
  * Fail conductor startup if invalid defaults exist
  * Add dynamic interfaces fields to base node notification
  * Improve conductor driver validation at startup
  * Remove iSCSI deploy support for IPA Mitaka
  * Add the timeout parameter to relevant methods in the fake power interface
  * Add hardware type 'irmc' for FUJITSU PRIMERGY servers
* Thu Feb  2 2017 cloud-devel@suse.de
- Update to version ironic-6.3.0.dev728:
  * Do not change admin_state for tenant port
  * Use delay configoption for ssh.SSHPower drivers
  * Adding clean-steps via json string examples
  * Remove deprecated heartbeat policy check
  * Add sem-ver flag so pbr generates correct version
  * Fix a few docstring warnings
  * Remove deprecated [deploy]erase_devices_iterations
  * Remove support for driver object periodic tasks
  * Log reason for hardware type registration failure
  * Duplicated code in ..api.get_active_driver_dict()
  * Allow using resource classes
  * DevStack: Only install edk2-ovmf on Fedora
  * Don't override device_owner for tenant network ports
  * Update guide for PXE multi-architecture setup
* Wed Feb  1 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev700:
  * [Devstack] Add stack user to libvirt group
  * Add soft reboot, soft power off and power timeout to api-ref
  * Add dynamic interfaces fields to nodes API
  * Add dynamic driver functionality to REST API
* Tue Jan 31 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev692:
  * [Devstack] Download both disk and uec images
  * [Devstack] Set DEFAULT_IMAGE_NAME variable
  * Update the outdated link in user-guide
  * Add Inject NMI to api-ref
* Sat Jan 28 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev684:
  * Switch to decorators.idempotent_id
  * Updated from global requirements
  * Follow-up iRMC driver doc update
  * Devstack: Create a "no ansi" logfile for the baremetal console logs
  * DevStack: Fix cleaning up nodes with NVRAM (UEFI)
* Fri Jan 27 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev674:
  * Add hardware type for IPMI using ipmitool
  * [Devstack] enable only pxe|agent_ipmitool by default
  * Update iRMC driver doc for soft reboot and soft power off
  * Correctly cache "abortable" flag for manual clean steps
* Thu Jan 26 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev668:
  * Fix broken link in the iLO driver docs
  * iRMC power driver for soft reboot and soft power off
  * Update proliantutils version required for Ocata release
  * Use global vars for storing image deploy path's
  * Onetime boot when set_boot_device isn't persistent
* Wed Jan 25 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev658:
  * Fix rel note format of the new feature Inject NMI
  * iRMC management driver for Inject NMI
  * Revert "Revert "Remove ClusteredComputeManager""
  * Use context manager for better file handling
  * Updated from global requirements
  * Fix typo in the metrics.rst file
  * Allow to use no nova installation
  * Fix api-ref warnings
  * Turn NOTE into docstring
  * Updated from global requirements
  * Ipmitool management driver for Inject NMI
  * Generic management I/F for Inject NMI
  * Clean up driver_factory.enabled_supported_interfaces
  * Add hardware types to the hash ring
  * Do not use user token in neutron client
  * Use only Glance V2 by default (with a compatibility option)
  * DevStack: Configure nodes/environment to boot in UEFI mode
  * Add tests for Payloads with SCHEMAs
  * Update multi-tenancy documentation
* Fri Jan 20 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev622:
  * Default ironic to not use nested KVM
  * Enable manual-management hardware type in devstack
  * Register/unregister hardware interfaces for conductors
  * Validate the generated swift temp url
  * Move to tooz hash ring implementation
* Thu Jan 19 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev613:
  * Add VIFs attach/detach to api-ref
  * make sure OVS_PHYSICAL_BRIDGE is up before bring up vlan interface
  * Expose default interface calculation from driver_factory
  * Add default column to ConductorHardwareInterfaces
* Wed Jan 18 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev605:
  * Update troubleshooting docs on no valid host found error
  * Do not fail in Inspector.__init__ if [inspector]enabled is False
  * Use TENANT_VIF_KEY constant everywhere
  * Updated from global requirements
* Tue Jan 17 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev599:
  * Allow to attach/detach VIF to portgroup
  * Refactor DRAC driver boot-device tests
  * Updated from global requirements
  * Remove check for UEFI + Whole disk images
  * Ipmitool power driver for soft reboot and soft power off
  * Ensures that OneView nodes are free for use by Ironic
  * Move baremetal tempest config setting from devstack
* Sat Jan 14 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev586:
  * Updated from global requirements
  * Update validate_ports from BaremetalBasicOps
  * Fix take over of ACTIVE nodes in AgentDeploy
* Fri Jan 13 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev581:
  * Allow to set min,max API microversion in tempest
  * Skip VIF api tests for old api versions
  * Fix assertEqual parmeters position in unittests
  * Move default image logic from DevStack to Ironic
  * Fix logging if power interface does not support timeout
  * Fix take over for ACTIVE nodes in PXEBoot
  * Don't translate exceptions w/ no message
* Thu Jan 12 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev567:
  * Document HCTL for root device hints
  * Add Virtual Network Interface REST APIs
  * Add lsblk to ironic-lib filters
  * Updated from global requirements
  * Correct logging of loaded drivers/hardware types/interfaces
  * Fix bashate warning in devstack plugin
* Wed Jan 11 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev556:
  * Add docs about creating release note when metrics change
  * Remove greenlet useless requirement
  * Revert "Disable placement-api by default"
  * Update regenerate-samples.sh api-ref script
* Tue Jan 10 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev549:
  * Change object parameter of swift functions
  * Add a NodePayload test
* Mon Jan  9 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev545:
  * Fixes grammar in the hash_partition_exponent description
* Sat Jan  7 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev543:
  * Remove service argument from tempest plugin client manager
  * Remove netaddr useless requirement
  * Generic power interface for soft reboot and soft power off
* Fri Jan  6 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev537:
  * Fix the comma's wrong locations
  * Create a table to track loaded interfaces
* Wed Jan  4 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev534:
  * Remove trailing backtick
  * 'updated_at' field value after node is updated
  * Clean up object code
* Tue Jan  3 2017 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev529:
  * Updated from global requirements
* Sat Dec 31 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev528:
  * Remove 'fork' option from socat command
  * Set access_policy for messaging's dispatcher
* Fri Dec 30 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev524:
  * Add Virtual Network Interface RPC APIs
  * Catch unknown exceptions in validate driver ifaces
  * Fix wrong exception message when deploy failed
  * Wrap iscsi portal in []'s if IPv6
* Thu Dec 29 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev516:
  * Disable placement-api by default
  * Add Virtual Network Interface Driver APIs
  * Add node console notifications
  * Add node maintenance notifications
  * Add ironic resources CRUD notifications
  * Auto-set nullable notification payload fields when needed
  * Add storage_interface to base driver class
  * Add storage_interface to node DB table
* Wed Dec 28 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev501:
  * Updated from global requirements
* Sun Dec 25 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev499:
  * Configure tempest for multitenancy/flat network
* Sat Dec 24 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev497:
  * Update dev-quickstart: interval value cannot be -1
* Thu Dec 22 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev495:
  * Add API reference for portgroup's mode and properties
  * Forbid removing portgroup mode
* Wed Dec 21 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev491:
  * Add test to ensure policy is always authorized
* Tue Dec 20 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev489:
  * Fix policy dict checkers
  * Updated from global requirements
  * Remove grenade config workaround
  * Adds another validation step when using dynamic allocation
  * Remove agent vendor passthru completely
* Sat Dec 17 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev480:
  * Introduce generic hardware types
  * Remove iBoot, WoL and AMT drivers
  * Move CONF.service_available.ironic to our plugin
* Fri Dec 16 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev474:
  * Add portgroup configuration fields
  * DevStack: Make $IRONIC_IMAGE_NAME less dependent of the name in DevStack
  * Make CONF.debug also reflect on IPA
* Fri Dec 16 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev468:
  * Revert "Change liberty's reno page to use the tag"
  * Update multitenancy docs
  * Use oslo_serialization.base64 to follow OpenStack Python3
  * Updated from global requirements
  * Fail ironic startup if no protocol prefix in ironic api address
* Thu Dec 15 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev459:
  * Support defining and loading hardware types
  * Change liberty's reno page to use the tag
  * Fix error when system uses /usr/bin/qemu-kvm, as in CentOS 7.2
  * Fix return values in OneView deploy interface
  * Clarify the comment about the object hashes
  * Reusing oneview_client when possible
  * Enhance wait_for_bm_node_status waiter
* Wed Dec 14 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev445:
  * Use polling in set_console_mode tempest test
  * Remove agent vendor passthru from OneView drivers
  * devstack: add vnc listen address
  * Remove deprecation of snmp drivers
  * Remove agent vendor passthru from iLO drvers
* Sat Dec 10 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev436:
  * Autospec ironic-lib mocks, fix test error string
  * Allow setting dhcp_provider in devstack
  * Fix default value of "ignore_req_list" config option
  * Add unit test for create_node RPC call
* Fri Dec  9 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev430:
  * Documentation for Security Groups for baremetal servers
  * Mock ironic-lib properly in test_deploy_utils
* Thu Dec  8 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev426:
  * Updated from global requirements
  * Add release names & numbers to API version history
  * Remove the VALID_ROOT_DEVICE_HINTS list
  * Make "enabled_drivers" config option more resilient to failures
  * Fix double dots at the end of a message to single dot
  * Use IronicObject._from_db_object_list method
* Wed Dec  7 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev414:
  * Update help for 'provisioning_network' option
  * Add virtualpdu to ironic devstack plugin
  * Add volume_connectors and volume_targets to task
* Tue Dec  6 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev409:
  * Updated from global requirements
  * Auto enable the deploy driver
  * Fix import method to follow community guideline
  * Turn off tempest's multitenant network tests
  * Remove agent vendor passthru from most drivers
* Sat Dec  3 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev399:
  * Renaming audit map conf sample file
  * Support names for {cleaning,provisioning}_network
  * Allow use *_ipmitool with vbmc on multinode
  * Add RPCs to support volume target operations
  * Add VolumeTarget object
  * Unneeded testing in DB migration of volume connector
  * Cleanup adding Ironic to cluster on upgrade case
  * Update the links in iLO documentation
  * Increase verbosity of devstack/lib/ironic
* Fri Dec  2 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev382:
  * Add volume_targets table to database
  * Move interface validation from API to conductor side
  * Make all IronicExceptions RPC-serializable
* Thu Dec  1 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev377:
  * Do not source old/localrc twise in grenade
  * Fix docs error about OOB RAID support
  * Follow-up for volume connector db_id
  * Install syslinux package only for Wheezy / Trusty
  * Add RPCs to support volume connector operation
  * Rely on portgroup standalone_ports_supported
* Wed Nov 30 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev366:
  * Remove file prefix parameter from lockutils methods
  * Update iptables rules and services IPs for multinode
* Tue Nov 29 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev362:
  * Show team and repo badges on README
  * Drac: Deprecate drac_host property
  * Add devstack setup_vxlan_network()
* Sat Nov 26 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev356:
  * Update keystone_authtoken configuration sample in the install guide
  * Add VolumeConnector object
  * Add volume_connectors table to save connector information
* Fri Nov 25 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev350:
  * Minor changes to neutron security groups code
  * Updated from global requirements
  * Skip some steps for multinode case
* Thu Nov 24 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev344:
  * Drop bad skip check in tempest plugin
  * Correct DB Interface migration test
  * Add support for Security Groups for baremetal servers
  * Add user and project domains to ironic context
* Wed Nov 23 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev336:
  * mask private keys for the ssh power driver
  * Convert iPXE boot script to Jinja template
  * Move `deploy_forces_oob_reboot` to deploy drivers
* Tue Nov 22 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev330:
  * Remove deprecated Neutron DHCP provider methods
  * Add notification documentation to install guide
  * Fix the message in the set_raid_config method
  * Fix PXE setup for fresh Ubuntu Xenial
  * Add node (database and objects) fields for all interfaces
  * Add node provision state change notification
  * Update the alembic migration section in the developer FAQ
  * Use function is_valid_mac from oslo.utils
  * Fix exception handling in iscsi_deploy.continue_deploy
* Sat Nov 19 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev312:
  * Add route to Neutron private network
* Fri Nov 18 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev311:
  * Add notification documentation to administrator's guide
  * Revert "Remove ClusteredComputeManager"
  * Remove ClusteredComputeManager
  * Followup to 0335e81a8787
  * Timing metrics: iRMC drivers
  * Enable PXE for systems using petitboot
* Thu Nov 17 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev299:
  * Docs: Document using operators with root device hints
  * Add portgroup to api-ref
  * Updated from global requirements
* Wed Nov 16 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev294:
  * Bring configurations from tempest to ironic_tempest_plugin
  * Timing metrics: OneView drivers
  * Update ironic node names for multinode case
* Mon Nov 14 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev288:
  * Do not pass ipa-driver-name as kernel parameter
  * Add unit test for microversion validator
  * Update devstack provision net config for multihost
  * Create dummy interfaces for use with hardware types
* Sat Nov 12 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev280:
  * Add possibility to remove chassis_uuid from a node
  * Simplify base interfaces in ironic.drivers.base
  * Add the way to get the deploy ram disks
* Fri Nov 11 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev274:
  * Add CI documentation outline
  * Fix typo in release note filename
* Thu Nov 10 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev270:
  * [install-guide] describe service clients auth
  * Integrate portgroups with ports to support LAG
  * Updated from global requirements
  * Update to hacking 0.12.0 and use new checks
  * DevStack: Fix standard PXE on Ubuntu Xenial
  * DevStack: Support for creating UEFI VMs
* Wed Nov  9 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev259:
  * Add PS4 for better logfile information of devstack runs
  * Update guide section for messaging setup
  * Updated from global requirements
  * Replaces uuid.uuid4 with uuidutils.generate_uuid()
  * Fix typo of 'authenticaiton'
* Tue Nov  8 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev250:
  * Add a unit test for microversion validation V1.22
  * Clean up unit test of API root test
  * Clarify ironic governance requirements and process
* Sat Nov  5 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev244:
  * Skip db configuration on subnodes
  * Ignore required_services for multinode topology
* Fri Nov  4 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev240:
  * Add PortGroups API
  * Updated from global requirements
  * Do not hide unexpected exceptions in inspection code
* Thu Nov  3 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev235:
  * API: lookup() ignore malformed MAC addresses
  * DRAC get_bios_config() passthru causes exception
  * Log currently known iSCSI devices when we retry waiting for iSCSI target
* Wed Nov  2 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev229:
  * TrivialFix: Fix typo in config file
  * Use kvm for ironic VMs when possible
  * Correct log the node UUID on failure
* Sat Oct 29 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev224:
  * Updated from global requirements
  * Change 'writeable' to 'writable'
* Thu Oct 27 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev220:
  * Remove use of 'vconfig' command in devstack ironic script
  * Updated from global requirements
  * Revert "Set SUBNETPOOL_PREFIX_V4 to FIXED_RANGE"
* Wed Oct 26 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev214:
  * Imported Translations from Zanata
* Sat Oct 22 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev213:
  * Use function import_versioned_module from oslo.utils
  * Updated from global requirements
  * Remove "dhcp" command from the iPXE template
* Fri Oct 21 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev208:
  * IPMI command should depend on console type
  * Remove ..agent.build_instance_info_for_deploy() in Pike
  * Always return chassis UUID in node's API representation
* Thu Oct 20 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev202:
  * Trivial fix of notifications doc
  * Refactor _test_build_pxe_config_options tests
* Wed Oct 19 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev199:
  * Trivial: fix typo in docstring
  * Add a missing error check in ipmitool driver's reboot
  * Adding Timing metrics for DRAC drivers
  * Remove 'agent_last_heartbeat' from node.driver_internal_info
  * Skip create_ovs_taps() for multitenancy case
  * Updated from global requirements
  * Fixes parameters validation in SSH power manager
  * Add entry_point for oslo policy scripts
* Tue Oct 18 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev185:
  * Add power state change notifications
  * Remove unnecessary '.' before ':' in ironic rst
  * Clean up provision ports when reattempting deploy
  * Move build_instance_info_for_deploy to deploy_utils
* Mon Oct 17 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev177:
  * Imported Translations from Zanata
  * Replace parse_root_device_hints with the ironic-lib version one
  * Fix API docs to include API version history
  * Update configure_tenant_networks
  * Change 'decom' to clean/cleaning
* Sat Oct 15 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev167:
  * fix a typo in document
  * Updated from global requirements
  * Remove "agent_last_heartbeat" internal field from agent drivers
* Fri Oct 14 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev162:
  * No need to clear "target_provision_state" again from conductor
  * Trivial: fix warning message formatting
  * Updated from global requirements
  * Fix some typos
  * Add docs about releasing ironic projects
  * Avoid name errors in oneview periodics
  * A few fixes in Multitenancy document
  * Introduce default_boot_option configuration option
  * Remove wrong check from conductor periodic task
  * Clarify when oneview node can be managed by ironic
  * Cleanup unused (i)PXE kernel parameters
  * Update ironic config docs for keystone v3
  * Support multi arch deployment
* Thu Oct 13 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev136:
  * Fix unit tests failing with ironic-lib 2.1.1
  * Add description for vendor passthru methods
  * Remove unneeded exception handling from conductor
  * Remove unused argument in Tempest Plugin
  * Fix docstrings to match with method arguments
* Wed Oct 12 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev129:
  * Fix broken xenial job
  * Fix setting custom IRONIC_VM_NETWORK_BRIDGE
  * Remove reservation from sync power states db filter
  * Log node state transitions at INFO level
* Mon Oct 10 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev122:
  * Fix a typo in deploy.py
  * Updated from global requirements
* Sat Oct  8 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev119:
  * Add tense guide to release note FAQ
  * Imported Translations from Zanata
  * Fix undisplayed notes in Quick-Start
* Fri Oct  7 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev114:
  * OneView driver docs explaining hardware inspection
  * Enable release notes translation
  * Remove unnecessary option from plugin settings
  * Set SUBNETPOOL_PREFIX_V4 to FIXED_RANGE
  * Enable DeprecationWarning in test environments
  * Fix _lookup() method for node API routing
  * Add inspection feature for the OneView drivers
  * Have bashate run for entire project
* Thu Oct  6 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev100:
  * Clean exceptions handling in conductor manager
  * Keep numbering of list in Install Guide
  * Fix docstrings in tempest plugin baremetal json client
  * Cleanup get_ilo_license()
  * Update configuration reference link to latest draft
  * Update external links to developer documentation
  * Use six.StringIO instead of six.moves.StringIO
  * Documentation change for feature updates in iLO drivers
* Wed Oct  5 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev85:
  * [install-guide] describe pxe.ipxe_swift_tempurl
  * Remove unused methods in common/utils.py
  * Do not use mutable object as func default param
  * Trivial: Fix some typos in comments and docstring
  * Use method delete_if_exists from oslo.utils
  * Change links to point to new install guide
  * Fix typos in docstring/comments
  * Fixing Typo
  * Add more details to MIGRATIONS_TIMEOUT note
  * Fix iLO drivers to not clear local_gb if its not detected
* Tue Oct  4 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev65:
  * doc: Add oslo.i18n usage link
  * Replace assertTrue(isinstance()) with assertIsInstance()
  * Fix typo: remove redundant 'the'
  * Invalid URL and Typo in enrollment.rst
* Sun Oct  2 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev57:
  * Move flavor create under 'VIRT_DRIVER == ironic'
* Sat Oct  1 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev55:
  * Updated from global requirements
  * Use assertRaises() instead of fail()
  * Fix grenade jobs
  * Add a missing whitespace to an error message
  * Fail test if excepted error was not raised
  * Remove unused method is_valid_ipv6_cidr
  * Support https in devstack plugin
* Fri Sep 30 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev43:
  * iLO drivers documentation update
* Thu Sep 29 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev42:
  * Use correct option value for standalone install
  * Fix inexact config option name in multitenancy.rst
* Wed Sep 28 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev38:
  * Fix docstring typo in test_common.py
  * Fix invalid git url in devstack/local.conf sample
  * Fix absolute links to install-guide.rst in developer docs
  * Update developer's guide "Installation Guide" link
  * Add link to new guide in old install guide
  * [install-guide] Import "Setup the drivers for the Bare Metal service"
  * [install-guide] Import "Trusted boot with partition image"
  * [install-guide] Import "Building or downloading a deploy ramdisk image"
  * [install-guide] Import "Appending kernel parameters to boot instances"
  * [install-guide] Import configdrive
  * [install-guide] Import HTTPS, standalone and root device hints
  * [install-guide] Import "Enrollment" and "Troubleshooting" sections
  * [install-guide] Import "Local boot with partition images"
  * [install-guide] Import "Flavor creation"
  * [install-guide] Import "Image requirements"
  * [install-guide] Import "integration with other OpenStack components"
  * [install-guide] Import Install and configure sections
  * [install-guide] Import "Bare Metal service overview"
* Sat Sep 24 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev17:
  * Remove unneeded try..except in heartbeat
  * Fix a typo in helper.py
  * Fixes wrong steps to perform migration of nodes
  * Update reno index for Newton
  * Add i18n _() to string
  * DevStack: Use Jinja2 for templating when creating new VMs
  * [api-ref] Correcting type of r_addresses parameter
* Fri Sep 23 2016 cloud-devel@suse.de
- Update to version ironic-6.2.1.dev6:
  * Increase timeout for migration-related tests
  * Change the logic of selecting image for tests
  * Updated from global requirements
  6.2.0
  * Fix DRAC passthru 'list_unfinished_jobs' desc
* Thu Sep 22 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev255:
  * Clean up release notes for 6.2.0
  * DRAC: list unfinished jobs
  * Fix broken unit tests for get_ilo_object
  * Sync ironic-lib.filters from ironic-lib
  * Remove websockify from requirements
  * Add a note about security groups in install guide
* Wed Sep 21 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev245:
  * Remove unnecessary setUp
  * Adds a missing space in a help string
  * Remove duplicated line wrt configdrive
  * Notification event types have status 'error'
  * Refactor common checks when instantiating the ipmitool classes
  * Grub2 by default for PXE + UEFI
  * Support configdrive in iscsi deploy for whole disk images
  * Remove NotificationEventTypeError as not needed
  * Mark untested drivers as unsupported
  * [trivial] Fix typo in docstring
  * Replace "phase" with "status" in notification base
  * Updated from global requirements
  * Fix test syntax error in devstack/lib/ironic
  * Separate WSGIService from RPCService
  * Update proliantutils version required for Newton release
  * Fix docstrings in Tempest Plugin REST client for Ironic API
  * Use assertEqual() instead of assertDictEqual()
  * Configure clean network to provision network
  * Allow using TempURLs for deploy images
  * Deprecate ClusteredComputeManager
* Fri Sep 16 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev208:
  * Fix link from doc index to user guide
* Thu Sep 15 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev207:
  * Fix DRAC failure during automated cleaning
  * Timing metrics: iLO drivers
* Wed Sep 14 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev203:
  * Remove cyclic import between rpcapi and objects.base
  * Fix nits on DRAC OOB inspection patch
* Tue Sep 13 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev200:
  * Replace six iteration methods with standard ones
  * Updated from global requirements
  * __ne__() unit tests & have special methods use (self, other)
* Sun Sep 11 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev194:
  * Add metrics to administrator guide
  * Update the string format
* Sat Sep 10 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev190:
  * Add a basic install guide
* Fri Sep  9 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev188:
  * Add __ne__() function for API Version object
  * Update unit tests for neutron interface
  * Update ironic/ironic.conf.sample
  * Log a warning for unsupported drivers and interfaces
  * [api-ref] Remove temporary block in conf.py
* Thu Sep  8 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev179:
  * Deny chassis with too long description
* Wed Sep  7 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev177:
  * Remove unused file: safe_utils.py
* Tue Sep  6 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev176:
  * Update driver requirement for iRMC
* Sat Sep  3 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev174:
  * DRAC OOB inspection
  * Remove neutron client workarounds
* Fri Sep  2 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev170:
  * Refresh fsm in task when a shared lock is upgraded
  * Updated from global requirements
  * Fix exception handling in NodesController._lookup
  * Remove unused LOG and CONF
  * Fix updating port.portgroup_uuid for node
  * Add a newline at the end of release note files
  * Replace DOS line endings with Unix
  * Update test_update_portgroup_address_no_vif_id test
  * Add standalone_ports_supported to portgroup - DB
  * DevStack: Configure retrieving logs from the deploy ramdisk
  * Fix incorrect order of params of assertEqual()
* Thu Sep  1 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev149:
  * Fix ironic-multitenant-network job
  * Metrics for ConductorManager
  * Allow suppressing ramdisk logs collection
  * OneView test nodes to use dynamic allocation
* Wed Aug 31 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev142:
  * Use assertIsInstance/assertNotIsInstance in tests
  * Config logABug feature for Ironic api-ref
* Wed Aug 31 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev139:
  * DRAC RAID configuration
  * Adds instructions to perform nodes migration
* Tue Aug 30 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev135:
  * Option to enroll nodes with drac driver
  * Fix pep8 on Python3.5
  * Updated from global requirements
  * Fix for check if dynamic allocation model is enabled
  * Add multi-tenancy section to security doc
  * Fix formatting strings in LOG.error
  * Mask instance secrets in API responses
  * Update documentation for keystone policy support
  * Fix typo in policy.json.sample
  * Add metrics for the ipminative driver
* Sat Aug 27 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev118:
  * Switch Inspector interface to pass keystoneauth sessions
* Fri Aug 26 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev116:
  * Add node serial console documentation
  * Prevent URL collisions with sub-controllers: nodes/ports
  * Centralize Config Options - patch merge, cleanup
  * Update the webapi version history reference
  * Fix fall back to newer keystonemiddleware options
  * Updated from global requirements
  * Update hacking test-requirement
  * Removed unneeded vlan settings from neutron config
  * Pass swiftclient header values as strings
  * Fix iLO drivers inconsistent boot mode default value
* Thu Aug 25 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev95:
  * Fix issues in dev-quickstart and index
  * Updated from global requirements
  * Add notification base classes and docs
* Wed Aug 24 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev89:
  * Documentation update
  * Move console documentation to separate file
  * Update api-ref for v1.22
  * Centralize config options - [iscsi]
* Tue Aug 23 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev82:
  * Replace DB API call to object's method in iLO drivers
  * Move "server_profile_template_uri" to REQUIRED_ON_PROPERTIES
  * Using assertIsNone() is preferred over assertEqual()
  * Updated from global requirements
  * Get ready for os-api-ref sphinx theme change
* Mon Aug 22 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev73:
  * Log node uuid rather than id when acquiring node lock
* Sun Aug 21 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev71:
  * Updated from global requirements
  * Remove incorrect CONF.import_opt() from test_ipmitool.py
* Sat Aug 20 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev68:
  * Update code to use Pike as the code name
  * Operator documentation for multitenancy
  * Always set DEFAULT/host in devstack
  * Fix AgentDeploy take_over() docstring
  * Fix key word argument interface_type -> interface
  * Centralize config options - [pxe]
* Fri Aug 19 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev56:
  * Allow changing lock purpose on lock upgrade
  * Fix typo: interations -> iterations
  * Clean imports in code
  * Copy iPXE script over only when needed
  * Fix incorrect order of params of assertEqual()
  * Fix test_find_node_by_macs test
  * Use memory mode for sqlite in db test
  * DevStack: No need to change the ramdisk filesystem type
  * Adding InfiniBand Support
  * Remove CONF.import_opt() from api/controllers/v1/node.py
* Thu Aug 18 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev36:
  * Update readme file
* Wed Aug 17 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev34:
  * Bring upgrade documentation up to date
* Tue Aug 16 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev32:
  * Use upper-constraints for all tox targets
  * Add nova scheduler_host_subset_size option to docs
  * Fix the description of inspection time fields
  * Fix incorrect order of params of assertEqual() in test_objects.py
  * Fix assertEqual(10, 10) in unit/api/v1/test_utils.py
  * Update renos for fix to ipmi's set-boot-device
  * Document retrieving logs from the deploy ramdisk
  * DevStack guide: Bump IRONIC_VM_SPECS_RAM to 1280
  * 'As of' in documentation is incorrect
* Sat Aug 13 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev18:
  * Doc: Recommend users to update their systems
  * Add "erase_devices_metadata_priority" config option
  * Updated from global requirements
  * Fix updating port MAC address for active nodes
* Fri Aug 12 2016 cloud-devel@suse.de
- Update to version ironic-6.1.1.dev10:
  * Remove unused [pxe]disk_devices option
  * IPMINative: Check the boot mode when setting the boot device
  * IPMITool: Check the boot mode when setting the boot device
  * Fix ssh credential validation message
  6.1.0
  * Rename some variables in test_ipminative.py
  * Update proliantutils version required for Newton release
  * Refactor OneView dynamic allocation release notes
  * Clean up release notes for 6.1.0
  * Refactor multitenant networking release notes
  * Updated Dev quickstart for viewing doc changes
  * Remove duplicate parameters from local.conf example
  * Check keyword arguments
  * Deprecate putting periodic tasks on a driver object
  * Updated from global requirements
  * test_console_utils: using mock_open for builtin open()
  * Update devstack configure_ironic_ssh_keypair
  * Trivial: Remove useless function call in glance service test
  * Simplify code by using mask_dict_password (again)
  * Officially deprecate agent passthru classes and API
  * Timing metrics: pxe boot and iscsi deploy driver
  * Fix the mistakes in Installation Guide doc
  * Use devstack test-config phase
  * Rename BaseApiTest.config to app_config
  * Documentation fixes for iLO SSL Certificate feature
  * Metrics for agent client
  * Simplify code by using mask_dict_password
  * OneView driver docs explaining Dynamic Allocation
  * Docs: Run py34 tox test before py27
  * Collect deployment logs from IPA
  * Fix typo
  * Remove oslo-incubator references
  * Promote agent vendor passthru to core API
  * Update add nova user to baremetal_admin behaviour
  * Fix typo in Install-guide.rst file
  * Replacing generic OneViewError w/ InvalidNodeParameter
  * Add Dynamic Allocation feature for the OneView drivers
  * Fix __all__ module attributes
  * Fix tempest realted exceptions during docs build
  * Add keystone policy support to Ironic
  * Follow up to keystoneauth patch
  * Add a data migration to fill node.network_interface
  * Test that network_interface is explicitly set on POST/PATCH
  * Updated from global requirements
  * Create a custom StringField that can process functions
  * Revert "Devstack should use a prebuilt ramdisk by default"
  * Fix for "db type could not be determined" error message
  * Update devstack plugin with new auth options
  * Migrate to using keystoneauth Sessions
  * Updating dev quickstart to include compatiblity for newest distros
  * Update nova scheduler_host_manager config docs
  * Extend the "configuring ironic-api behind mod_wsgi" guide
  * Add metrics for the ipmitool driver
  * Timing metrics for agent deploy classes
  * Pass agent metrics config via conductor
  * Minor docstring and unittests fixes for IPMIConsole
  * Move default network_interface logic in node object
  * Updated from global requirements
  * Devstack should use a prebuilt ramdisk by default
  * Updated tests for db migration scripts
  * Centralize config options - [agent]
  * Log full config only once in conductor
  * Add node.resource_class field
  * Add api-ref for new port fields
  * Add support for the audit middleware
  * Change comment regarding network_interface
  * Fix rendering for version 1.14
  * Use 'UUID', not 'uuid' in exception strings
  * IPMITool: add IPMISocatConsole and IPMIConsole class
  * Use assertEqual() instead of assertDictEqual()
  * Remove unused code when failing to start console
  * Trivial: Fix a trivial flake8 error
  * Centralize config options - [deploy]
  * Centralize config options - [api]
  * Added note to local.conf addressing firewall/proxy blocking Git protocol
  * Bug fixes and doc updates for adoption
  * Do the VM setup only when requested
  * Remove unused import
  * Remove duplicate copyright
  * Add build-essential to required packages for development
  * Implement new heartbeat for AgentDeploy
  * Add Python 3.5 tox venv
  * Updated from global requirements
  * Doc update for in-band cleaning support on more drivers
  * Updated from global requirements
  * Support to validate iLO SSL certificate in iLO drivers
  * Update {configure|cleanup}ironic_provision_network
  * Add test to verify ironic multitenancy
  * Add multitenancy devstack configuration examples
  * Following the hacking rule for string interpolation at logging
  * Centralize config options - [DEFAULT]
  * Add py35 to tox environments
  * Metric chassis, driver, node, and port API calls
  * Fix fake.FakeBoot.prepare_ramdisk() signature
  * Update devstack section of quickstart to use agent_ipmitool
  * Add configure_provision_network function
  * Add and document the "rotational" root device hint
  * Document API max_limit configuration option
* Sat Jul 16 2016 cloud-devel@suse.de
- Update to version ironic-6.0.1.dev134:
  * Follow-up to 317392
  * Follow-up patch of 0fcf2e8b51e7dbbcde6d4480b8a7b9c807651546
  * Updated from global requirements
  * Expose node's network_interface field in API
* Fri Jul 15 2016 cloud-devel@suse.de
- Update to version ironic-6.0.1.dev127:
  * Grammar fix in code contribution guide
  * Deprecate [ilo]/clean_priority_erase_devices config
  * Update Ironic VM network connection
  * Centralize config options - [neutron]
  * Nova-compatible serial console: socat console_utils
  * Updated from global requirements
  * Fix docstring warnings
* Thu Jul 14 2016 cloud-devel@suse.de
- Update to version ironic-6.0.1.dev113:
  * Follow-up fixes to 206244
  * Add multitenancy-related fields to port API object
  * Update the deploy drivers with network flipping logic
  * Add 'neutron' network interface
  * Add network interface to base driver class
  * Config variable to configure [glance] section
  * Add support for building ISO for deploy ramdisk
  * Allow to use network interfaces in devstack
* Wed Jul 13 2016 cloud-devel@suse.de
- Update to version ironic-6.0.1.dev98:
  * Increase devstack BM VM RAM for coreos to boot
  * Add a doc about appending kernel parameters to boot instances
  * Centralize config options - [glance]
* Tue Jul 12 2016 cloud-devel@suse.de
- Update to version ironic-6.0.1.dev92:
  * Trivial grammar fixes to the upgrade guide
  * Remove unused expected_filter in the unit test
  * Updated from global requirements
  * Remove white space between print and ()
  * Remove IBootOperationError exception
  * Fix two types in ironic.conf.sample
* Sat Jul  9 2016 cloud-devel@suse.de
- Update to version ironic-6.0.1.dev81:
  * Delete bios_wsman_mock.py from DRAC driver
  * Correct reraising of exception
  * Allow to enroll nodes with oneview driver
  * Add internal_info field to ports and portgroups
  * Remove iterated form of side effects
* Fri Jul  8 2016 cloud-devel@suse.de
- Update to version ironic-6.0.1.dev72:
  * Remove unused LOG
* Thu Jul  7 2016 cloud-devel@suse.de
- Update to version ironic-6.0.1.dev71:
  * Improve the readability of configuration drive doc part
* Wed Jul  6 2016 cloud-devel@suse.de
- Update to version ironic-6.0.1.dev69:
  * Drop IRONIC_DEPLOY_DRIVER_ISCSI_WITH_IPA from documentation
  * Centralize config options - [virtualbox]
  * Centralize config options - [swift]
  * Centralize config options - [ssh]
* Tue Jul  5 2016 cloud-devel@suse.de
- Update to version ironic-6.0.1.dev62:
  * Updated from global requirements
  * Centralize config options - [snmp]
  * Add network_interface node field to DB and object
  * Throwing an exception when creating a node with tags
  * Centralize config options - [seamicro]
  * Centralize config options - [oneview]
* Fri Jul  1 2016 cloud-devel@suse.de
- Update to version ironic-6.0.1.dev50:
  * Add Ironic specs process to the code contribution guide
* Thu Jun 30 2016 cloud-devel@suse.de
- Update to version ironic-6.0.1.dev48:
  * Add missing translation marker to clear_node_target_power_state
  * Improve tests for driver's parse_driver_info()
  * Centralize config options - [keystone]
* Wed Jun 29 2016 cloud-devel@suse.de
- Update to version ironic-6.0.1.dev42:
  * Fix typo in inspection.rst
  * Follow-up patch of 9a1aeb76da2ed53e042a94ead8640af9374a10bf
  * Centralize config options - [irmc]
  * Centralize config options - [ipmi]
  * Introduce new driver call and RPC for heartbeat
* Tue Jun 28 2016 cloud-devel@suse.de
- Update to version ironic-6.0.1.dev33:
  * Fix releasenotes formatting error
  * Centralize config options - [inspector]
  * Centralize config options - [ilo]
  * Remove unnecessary calls to dict.keys()
  * Fail early if ramdisk type is dib, and not building
  * Add dbapi and objects functions to get a node by associated MAC addresses
  * Drop references to RPC calls from user-visible errors
  * Centralize config options - [iboot]
  * Add validation of 'ilo_deploy_iso' in deploy.validate()
  * Clear target_power_state on conductor startup
  * Fix parameter create-node.sh
* Sat Jun 25 2016 cloud-devel@suse.de
- Update to version ironic-6.0.1.dev16:
  * Updated from global requirements
  * Replace dict.get(key) in api & conductor tests
  * Use PRIVATE_NETWORK_NAME for devstack plugin
  * Restore diskimage-builder install
  * Fix test in test_agent_client.py
  * Add Link-Local-Connection info to ironic port
* Fri Jun 24 2016 cloud-devel@suse.de
- Update to version ironic-6.0.1.dev7:
  * Create common neutron module
  * Updated from global requirements
  * Deployment vmedia operations to run when cleaning
* Thu Jun 23 2016 cloud-devel@suse.de
- Update to version ironic-6.0.1.dev3:
  * Properly set ephemeral size in agent drivers
  6.0.0
  * Updated from global requirements
  * Mask password on agent lookup according to policy
* Wed Jun 22 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev413:
  * Replace assertRaisesRegexp with assertRaisesRegex
  * Replace dict.get(key) in drivers unit tests
  * Centralize config options - [dhcp]
  * Centralize config options - [database]
  * Centralize config options - [conductor]
* Tue Jun 21 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev404:
  * Docs: Fix some typos in the documentation
  * Removes the use of mutables as default args
  * Replace dict.get(key) in drivers/modules/*/ tests
  * Document testing an in-review patch with devstack
  * Replace vif_portgroup_id with vif_port_id
* Mon Jun 20 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev394:
  * Use assertIn and assertNotIn
* Sat Jun 18 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev392:
  * Follow-up to Active Node Creation
  * Change port used for Ironic static http to 3928
  * Centralize config options - [cisco_ucs]
  * Centralize config options - [cimc]
  * Centralize config options - [console]
  * Fix typo in agent driver
  * Remove workaround for nova removing instance_uuid during cleaning
  * Active Node Creation via adopt state
* Fri Jun 17 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev377:
  * No need for 'default=None' in config variable
* Thu Jun 16 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev376:
  * Use assert_called_once_with in test_cleanup_cleanwait_timeout
  * Trivial comments fix
  * Document support for APC AP7921
  * fix sed strings in developer doc
  * Replace dict.get(key) with dict[key] in unit tests
* Wed Jun 15 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev367:
  * Updated from global requirements
  * Add cleanwait timeout cleanup process
  * Fix JSON error in documentation
* Tue Jun 14 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev361:
  * Add restrictions for changing portgroup-node association
  * Imported Translations from Zanata
  * Support for APC AP7922
* Sat Jun 11 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev356:
  * Remove support for the old ramdisk (DIB deploy-ironic element)
  * Updated from global requirements
  * Document packing and unpacking the deploy ramdisk
  * Fix nits related to Ports api-ref
  * Gracefully degrade start_iscsi_target for Mitaka ramdisk
  * Update the api-ref documentation for Drivers
  * Update comment from NOTE to TODO
  * Update resources subnet CIDR
  * remove neutron stuff from devstack deb packages
  * Keep original error message when cleaning tear down fails
  * Add config option for ATA erase fallback in agent
  * Fix markup in documentation
  * Imported Translations from Zanata
  * Updated from global requirements
  * Add debug environment to tox
  * Correct RAID documentation JSON
  * Added ironic-ui horizon dashboard plugin to ironic docs
  * Update the api-ref documentation for Ports
  * Add 'How to get a decision on something' to FAQ
* Fri Jun  3 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev321:
  * Updated from global requirements
  * Disable disk_config compute-feature-enabled in tempest
  * Make sure create_ovs_taps creates unique taps
  * NOTIFICATION_TRANSPORT should be global
  * Add one use case for configdrive
  * Add support for dib based agent ramdisk in lib/ironic
* Wed Jun  1 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev310:
  * Remove links to github for OpenStack things
  * Updated from global requirements
  * Remove hard-coded keystone version from setup
  * Use a single uuid parameter in api-ref
  * Remove support for 'hexraw' iPXE type
  * Use messaging notifications transport instead of default
* Tue May 31 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev298:
  * Use correct iscsi portal port in continue_deploy
  * Fix raises to raise an instance of a class
  * Fix formatting of a release note
  * Updated from global requirements
  * tempest: start using get_configured_admin_credentials
  * Remove backward compatibility code for agent url
  * Change HTTP_SERVER's default value to TFTPSERVER_IP
* Sat May 28 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev287:
  * Fix signature for request method
* Fri May 27 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev286:
  * Follow-up patch of 8e5e69869df476788b3ccf7e5ba6c2210a98fc8a
  * Introduce provision states: AVAILABLE, ENROLL
  * minor changes to security documentation
  * Make use of oslo-config-generator
  * Make the ssh driver work on headless VirtualBox machines
  * Allow to specify node arch
* Thu May 26 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev274:
  * Add support for API microversions in Tempest tests
  * Mention RFEs in README
  * Remove unused is_valid_cidr method
  * Remove "periodic_interval" config option
  * Remove deprecated driver_periodic_task
* Wed May 25 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev265:
  * Updated from global requirements
  * Joined 'tags' column while getting node
* Tue May 24 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev262:
  * Restart n-cpu after Ironic install
  * Move all cleanups to cleanup_ironic
  * Keep backward compatibility for openstack port create
  * Revert "Run smoke tests after upgrade"
  * Add some docs about firmware security
  * Update the api-ref documentation for Root and Nodes
  * devstack: Configure console device name
* Sat May 21 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev248:
  * Read the Sphinx html_last_updated_fmt option correctly in py3
  * Updated from global requirements
  * Replace project clients calls with openstack client
  * Fix start order for Ironic during upgrade
  * Add some docs/comments to devstack/plugin.sh
* Fri May 20 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev239:
  * Stop unit-testing processutils internals
  * Run smoke tests after upgrade
  * Remove link to Liberty configs
* Thu May 19 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev234:
  * Add ironic to enabled_services
  * Updated from global requirements
  * Fix shutdown.sh & upgrade.sh for grenade
  * add mitaka configuration reference link to the index page
  * Remove verbose option
  * Updated from global requirements
  * Eliminate warnings about rm in api-ref build
  * Remove backward compat for Liberty cleaning
  * Remove [conductor]/clean_nodes config option
  * Remove "message" attribute support from IronicException
  * Setup for using the Grenade 'early_create' phase
  * Remove deprecated [pxe]/http_* options
  * Remove [agent]/manage_tftp option
  * Remove "discoverd" configuration group
  * Migrate to os-api-ref library
  * Add require_exclusive_lock decorators to conductor methods
* Tue May 17 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev203:
  * Regenerate sample config
  * Doc: Replace nova image-list
  * Fix syntax error in devstack create-node script
  * Updated from global requirements
  * Allow vendor drivers to acquire shared locks
  * Modify doc for RAID clean steps in manual cleaning
  * Only install DIB if going to use DIB
  * DevStack: Support to install virtualbmc from source
  * Extend IRONIC_RAMDISK_TYPE to support 'dib'
* Sun May 15 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev187:
  * Make iPXE + TinyIPA the defaults for devstack
* Sat May 14 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev185:
  * Fix formatting error in releasenotes
* Fri May 13 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev184:
  * devstack: Fetch tarball images via https
* Thu May 12 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev183:
  * Regenerate sample configuration
  * Allow configuring shred's final overwrite with zeros
* Wed May 11 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev179:
  * Updated from global requirements
  * Cleanup unused conf variables
  * Adds RAID interface for 'iscsi_ilo'
* Mon May  9 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev175:
  * Pass environment through to create-node.sh
  * DevStack: Support to install pyghmi from source
  * RAID interface to support JBOD volumes
  * Remove ClusteredComputeManager docs
  * API: Check for reserved words when naming a node
  * File download fails with swift pseudo folder
  * Migrate api-ref into our tree
  * Updating dev-quickstart.rst file links
  * Devstack: allow extra PXE params
  * Updated from global requirements
  * Update resources only for specific node during deletion
  * Fix tox cover command
  * Fix VirtualBox cannot set boot device when powered on
  * Set root hints for disks less than 4Gb and IPA
  * Use Ironic node name for VM
  * Update compute_driver in documentation
  * Fix API node name updates
  * Fixed nits in the new inspection doc page
* Mon May  9 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev140:
  * Allow to sepecify VM disk format
  * Replace logging constants with oslo.log
* Mon May  9 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev136:
  * Follow-up patch of 0607226fc4b4bc3c9e1738dc3f78ed99e5d4f13d
* Mon May  9 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev134:
  * iscsi: wipe the disk before deployment
  * FIX: IPMI bmc_reset() always executed as "warm"
  * DevStack: Parametrize automated_clean
  * Very important single character typo fix
  * Remove two DEPRECATED config options from [agent]
  * Allow to set Neutron port setup delay from config
  * Fix usage of rest_client expected_success() in tests
  * ipxe: retry on failure
  * Restart consoles on conductor startup
  * Remove backwards compat for CLEANING
* Thu Apr 21 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev115:
  * Update ironic.config.sample
  * Imported Translations from Zanata
  * Updated from global requirements
  * Document how to run the tempest tests
  * Update the inspection documentation
  * Devstack: Change to use 'ovs-vsctl get port tag'
  * Make sure Cisco drivers are documented on IRONIC_DEPLOY_DRIVER
* Wed Apr 20 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev102:
  * Add note on prerequisite of 'rpm' file extraction
  * Use get_admin_context() to create the context object
* Thu Apr 14 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev99:
  * Remove two deprecated config option names from [agent] section
  * Updated from global requirements
  * Add support for Cisco drivers in Ironic devstack
  * add new portal_port option for iscsi module
  * Remove description of 'downgrade' for ironic-dbsync
  * Adopt Ironic's own context
* Wed Apr 13 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev87:
  * Updated from global requirements
  * [docstring] Update ironic/api/controllers/v1/__init__.py comment
* Tue Apr 12 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev84:
  * Fix tinyipa initrd tarballs.openstack.org file name
  * In node_power_action() add node.UUID to log message
  * deployment vmedia ops should not be run when not deploying
  * Force iRMC vmedia boot from remotely connected CD/DVD
  * Updating driver docs with DL hardwares requirements
  * Sync Oslo gettextutils  module to Ironic
  * Removed  templates directory in api config
* Tue Apr 12 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev76:
  * Prepare for transition to oslo-config-generator
* Mon Apr 11 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev74:
  * Rename juno name state modification method
  * Correct api version check conditional for node.name
  * Enable Grenade usage as a plugin
* Sat Apr  9 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev68:
  * Updated from global requirements
  * Allow user to specify cleaning network
  * Adjust ipminative._reboot to comply with pyghmi contract
* Fri Apr  8 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev65:
  * Reduce amount of unhelpful debug logging in the API service
* Thu Apr  7 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev63:
  * Enable download of tinyipa prebuilt image
  * Follow-up to I244c3f31d0ad26194887cfb9b79f96b5111296c6
  * Updated from global requirements
  * Don't power off non-deploying iLO nodes in takeover
  * Tune interval for node provision state check
  * Normalize MAC OctetString to fix InvalidMAC exception
* Wed Apr  6 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev51:
  * Fix NamedTemporaryFile() OSError Exception
  * Updated from global requirements
* Tue Apr  5 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev48:
  * Updated from global requirements
  * Make tox respect upper-constraints.txt
  * Move _normalize_mac to driver utils
* Sat Apr  2 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev43:
  * Fix _do_next_clean_step_fail_in_tear_down_cleaning()
  * Allow fetching IPA ramdisk with branch name
* Fri Apr  1 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev40:
  * Fix typo in devstack script
  * Note on ilo firmware update swift url scheme
  * Clean up test node post data
* Thu Mar 31 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev35:
  * Readability fixes for cleaning_reboot code
  * Support reboot_requested bool on agent clean_steps
  * Move testcases related to parse_instance_info()
  * Remove unneeded use of task.release_resources()
* Wed Mar 30 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev28:
  * Update tempest compute flavor_ref/flavor_ref_alt
  * Follow up patch of 843ce0a16160f2e2710ef0901028453cd9a0357c
* Tue Mar 29 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev24:
  * Assign valid values to UUIDFields in unit tests
  * Fix typos in some source files
* Sat Mar 26 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev20:
  * Improve check for ssh-key to include public and private files
  * Doc update to enable HTTPS in Glance and Ironic comm
* Fri Mar 25 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev17:
  * Fix: Duplicated driver causes conductor to fail
  * Use trueorfalse function instead of specific value
  * Update reno for stable/mitaka
  * Fix race in hash ring refresh unit test
  * Addressing nits on I2984cd9d469622a65201fd9d50f964b144cce625
  * Config to stop powering off nodes on failure
  * Delete bridge "brbm" in devstack/unstack.sh
  * [Devstack]Add ability to enable shellinabox SSL certificate
  * Update authorized_keys with new key only
  * Update ironic_ssh_check method
* Thu Mar 24 2016 cloud-devel@suse.de
- Update to version ironic-5.1.1.dev1:
  5.1.0
  * Add xinetd and its TFTP configuration in Install Guide
* Thu Mar 24 2016 cloud-devel@suse.de
- Update to version ironic-5.0.1.dev52:
  * Documentation update for partition image support
* Wed Mar 23 2016 cloud-devel@suse.de
- Update to version ironic-5.0.1.dev51:
  * Append 'Openstack-Request-Id' header to the response
  * Add disk_label and node_uuid for agent drivers
  * Fix sphinx docs build
  * Agent: Out-of-band power off on deploy
  * Document partition image support with agent_ilo
  * Update the text in user guide of ironic
  * Devstack: add check of chassis creating
* Tue Mar 22 2016 cloud-devel@suse.de
- Update to version ironic-5.0.1.dev37:
  * Add support for partition images in agent drivers
  * Translate requests exception to IronicException
  * Extend the Conductor RPC object
  * Make sure target state is cleared on stable states
  * Removes redundant "to"
  * Don't depend on existing file perm for qemu hook
  * Adds doc - firmware update(iLO) manual clean step
  * Add ensure_thread_contain_context() to task_manager
* Sat Mar 19 2016 cloud-devel@suse.de
- Update to version ironic-5.0.1.dev22:
  * Install apparmor b/c Docker.io has undeclared dep
  * Remove unneeded 'wait=False' to be more clean and consistent
* Thu Mar 17 2016 cloud-devel@suse.de
- Update to version ironic-5.0.1.dev18:
  * Follow-up of firmware update(iLO) as manual cleaning step
* Thu Mar 17 2016 cloud-devel@suse.de
- Update to version ironic-5.0.1.dev16:
  * [devstack] Do not die if neutron is disabled
  * Updating driver docs with DL hardwares requirements
  * Pass region_name to SwiftAPI
  * DevStack: Allow configuring the authentication strategy
* Wed Mar 16 2016 cloud-devel@suse.de
- Update to version ironic-5.0.1.dev8:
  * Add documentation for RAID
* Tue Mar 15 2016 cloud-devel@suse.de
- Update to version ironic-5.0.1.dev6:
  * Uses jsonschema library to verify clean steps
  * Fix important typo in the ipmitool documentation
* Mon Mar 14 2016 tbechtold@suse.com
- Update to version ironic-5.0.1.dev3:
  5.0.0
  * Add documentation about the disk_label capability
  * SSH driver: Remove pipes from virsh's list_{all, running}
  * Add documentation for the IPMITool driver
  * Fix error in cleaning docs
  * Replace depricated tempest-lib with tempest.lib
  * Add new 'disk_label' capability
  * Fix JSON string in example of starting manual cleaning
  * Remove 'grub2' option in creating whole-disk-images
  * Update iRMC driver doc for inspection
  * Don't use token for glance & check for some unset vars
  * Use 'baremetal' flavor in devstack
  * [devstack] Fix IPA source build on Fedora
  * DevStack: Enable VirtualBMC logs
  * Support for passing CA certificate in Ironic Glance Communication
  * Updated from global requirements
  * Firmware update(iLO) as manual cleaning step
  * Updated from global requirements
  * Remove code duplication
  * Update iLO documentation for clean step 'reset_ilo'
  * Refactor the management verbs check to utils
  * Updated from global requirements
  * Remove duplicate doc in ironic.conf.sample
  * Prep for 5.0 release
  * Fix unittests after new releases of libraries
  * Updating docs with support for DL class servers
  * Update CIMC driver docs to install ImcSdk from PyPi
  * Add returns to send_raw() ipmitool function
  * Add function for dump SDR to ipmitool driver
  * Add clean step in iLO drivers to activate iLO license
  * Update proliantutils version to 2.1.7 for Mitaka release
  * ipxe: add --timeout parameter to kernel and initrd
  * Updated iLO driver documentation to recommend ipmitool version
  * Refactor driver loading to load a driver instance per node
  * Clean up driver loading in init_host
  * add wipefs to ironic-lib.filters
  * Updated from global requirements
  * Use assertEqual/Greater/Less/IsNone
  * Follow up nits of 3429e3824c060071e59a117c19c95659c78e4c8b
  * API to list nodes using the same driver
  * [devstack] set ipa-debug=1 for greater debugability
  * Loose python-oneviewclient version requirement
  * Set node last_error in TaskManager
  * Add possible values for config options
  * Follow up nits of irmc oob inspection
  * Enable removing name when updating node
  * Make some agent functions require exclusive lock
  * Add db api layer for CRUD operations on node tags
  * Update proliantutils version required for Mitaka release
  * Add deprecated_for_removal config info in ironic.conf.sample
  * Update ironic.conf.sample
  * Tolerate roles in context.RequestContext
  * Switch to Futurist library for asynchronous execution and periodic tasks
  * Move _from_db_object() into base class
  * Add ironic_tempest_plugin to the list of packages in setup.cfg
  * Fix gate broken by sudden remove of SERVICE_TENANT_NAME variable
  * Add manual cleaning to documentation
  * Import host option in base test module
  * Fixes automated cleaning failure in iLO drivers
  * Updated from global requirements
  * DevStack: Add support for deploying nodes with pxe_ipmitool
  * Change the libvirt NIC driver to virtio
  * DevStack: Support to install diskimage-builder from source
  * [Devstack]Add ability to enable ironic node pty console
  * Use 'node' directly in update_port()
  * Add links to the standalone configdrive documentation
  * DevStack: Install squashfs-tools
  * [DevStack] fix restart of nova compute
  * Use http_{root, url} config from "deploy" instead of "pxe"
  * During cleaning, store clean step index
  * Use oslo_config.fixture in unit tests
  * Introduce driver_internal_info in code-contribution-guide
  * Updated from global requirements
  * Correct instance parameter description
  * Add node.uuid to InstanceDeploy error message
  * Set existing ports pxe_enabled=True when adding pxe_enabled column
  * Augmenting the hashing strategy
  * Add hardware inspection module for iRMC driver
  * Document possible access problems with custom IRONIC_VM_LOG_DIR path
  * Add documentation for proxies usage with IPA
  * Updated from global requirements
  * Devstack: create endpoint in catalog unconditionally
  * Comment out test options that already exists on tempest's tree
  * Replace config 'clean_nodes' with 'automated_clean'
  * Remove 'zapping' from code
  * Cache agent clean steps on node
  * API to manually clean nodes
  * Replace ifconfig with ip
  * Updated iLO documentation for boot mode capability
  * Agent vendor handles manual cleaning
  * Remove downgrade support from migrations
  * Enable tinyipa for devstack Ironic
  * Disable clean step 'reset_ilo' for iLO drivers by default
  * Add proxy related parameters to agent driver
  * Update ironic.conf.samle
  * Fix genconfig "tempdir" inconsistency
  * Update the home page
  * Follow-up on dracclient refactor
  * Log warning if ipmi_username/ipmi_password missing
  * Add portgroups to support LAG interfaces - net
  * Add portgroups to support LAG interfaces - RPC
  * Add portgroups to support LAG interfaces - objs
  * Add portgroups to support LAG interfaces - DB
  * Fix missing lookup() vendor method error for pxe_drac
  * Refresh ssh verification mechanism
  * Refactor install-guide to configure API/Conductor seperately
  * Enable Ironic Inspector for Cisco Drivers
  * Fix doc8's "duplicated target names" (D000) error
  * Remove conditional checking the auth_strategy values
  * Extend root device hints to support device name
  * Fix spawn error hook in "continue_node_clean" RPC method
  * Enable doc8 style checker for *.rst files
  * Updated from global requirements
  * Show transitions initiated by API requests
  * Remove hard-coded DEPLOYWAIT timeout from Baremetal Scenario
  * Fix tiny format issue with install_guide
  * Add priority to manual clean step example
  * Use node uuid in some exception log
  * Fix error message in devstack
  * Updated from global requirements
  * [devstack] Restart nova compute before checking hypervisor stats
  * Imported Translations from Zanata
  * Fix minor typo
  * DRAC: cleanup after switch to python-dracclient
  * API service logs access requests again
  * Updated from global requirements
  * Correct port_id parameter description
  * Remove duplicate words in API version history
  * Remove unneeded enable_service in dev-quickstart.rst
  * Clarify that size in root device hints and local_gb are often different
  * Update ImcSdk requirement to use PyPi
  * Clean up 'no_proxy' unit tests
  * Add more unit tests for NO_PROXY validation
  * Add ability to cache swift temporary URLs
  * DRAC: switch to python-dracclient on vendor-passthru
  * Migrate Tempest tests into Ironic tree
  * Use Tempest plugin interface
  * Fix issues with uefi-ipxe booting
  * Update links to OpenStack manuals
  * Fix issue where system hostname can impact genconfig
  * Add choices option to several options
  * Reorganize the developer's main page
  * Document backwards compat for passthru methods
  * Drop MANIFEST.in - it's not needed pbr
  * Clean up unneeded deprecated_group
  * Devstack: replace 'http' with SERVICE_PROTOCOL
  * Clarify rejected status in RFE contribution docs
  * Bring UP baremetal bridge
  * Document the process of proposing new features
  * Updated from global requirements
  * Use assertTrue/False instead of assertEqual(T/F)
  * devstack 'cleanup-node' script should delete OVS bridges
  * Change default IRONIC_VM_SPECS_RAM to 1024
  * Remove release differences from flavor creation docs
  * Add documentation for standalone ilo drivers
  * Devstack: Make sure libvirt's hooks directory exists
  * Update the ironic.conf.sample file
  * Follow-up on refactor DRAC management interface
  * Allow user to set arch for the baremetal flavor and ironic node
  * tox: make it possible to run pep8 on current patch only
  * Devstack: Use [deploy] erase_devices_priority config option
  * Remove bashate from envlist
  * Use ironic-lib's util methods
  * Refactor objects into a magic registry
  * Don't return tracebacks in API response in debug mode
  * Updated from global requirements
  * Change assertTrue(isinstance()) by optimal assert
  * Remove */openstack/common* in tox
  * Remove vim headers in source files
  * Trival: Remove unused logging import
  * Use ironic-lib's qemu_img_info() & convert_image()
  * Update "Developer Quick-Start" guide for Fedora 23+
  * Enable ironic devstack plugin in local.conf sample
  * Install 'shellinabox' package for Ironic
  * Conductor handles manual cleaning
  * Add documentation for user inputs as HTTPS URLs
  * DRAC: switch to python-dracclient on management interface
  * Remove override-defaults
* Sat Dec 26 2015 cloud-devel@suse.de
- Update to version ironic-4.3.1.dev112:
  * Correct a tiny issue in install-guide
* Fri Dec 25 2015 cloud-devel@suse.de
- Update to version ironic-4.3.1.dev110:
  * Fix translations in driver base
  * Run flake8 against the python scripts under tools/ and devstack/tools
  * Use the apache-ironic.template from our tree
* Thu Dec 24 2015 cloud-devel@suse.de
- Update to version ironic-4.3.1.dev105:
  * Add UEFI support for iPXE
  * Add console feature to ssh driver
  * Use imageutils from oslo.utils
* Wed Dec 23 2015 cloud-devel@suse.de
- Update to version ironic-4.3.1.dev99:
  * Add extensions to the scripts at devstack/tools/ironic/scripts
  * Fix "No closing quotation" error when building with tox
  * Devstack: Remove QEMU hook at ./unstack
  * Run bashate as part of the pep8 command
  * Fix bashate errors in grenade plugin
  * Fix syntax errors in the shell scripts under devstack/tools
  * Fix typo in ironic/conductor/manager.py
  * genconfig: Debug info for unknown config types
  * Keep the console logs for all boots
  * Clean up variables in plugin.sh
  * Add utility function to validate NO_PROXY
  * Add grenade plugin
  * Refactor disk partitioner code from ironic and use ironic-lib
* Thu Dec 17 2015 cloud-devel@suse.de
- Update to version ironic-4.3.1.dev75:
  * DRAC: switch to python-dracclient on power interface
  * Follow up nits of Exception to str type conversion
* Wed Dec 16 2015 cloud-devel@suse.de
- Update to version ironic-4.3.1.dev71:
  * Add bashate tox command
  * Updated from global requirements
  * Add documentation for swiftless intermediate images
  * Sequence diagrams for iLo driver documentation
  * Refactor ilo documentation for duplicate information
  * Update swift HTTPs information in ilo documentation
  * Simplifies exception message assurance for oneview.common tests
* Tue Dec 15 2015 cloud-devel@suse.de
- Update to version ironic-4.3.1.dev58:
  * Replace assertEqual(None, *) with assertIsNone in tests
  * Add bifrost as an option projects in Service overview
  * Deprecated tox -downloadcache option removed
  * Add FSM.is_stable() method
  * Validate arguments to clean_step() decorator
* Mon Dec 14 2015 cloud-devel@suse.de
- Update to version ironic-4.3.1.dev50:
  * Updated from global requirements
  * Update ironic.conf.sample by applying the bug fix #1522841
  * Remove extra space in 'host' config comment
* Sun Dec 13 2015 cloud-devel@suse.de
- Update to version ironic-4.3.1.dev44:
  * Use 'service_type' of 'network'. Not 'neutron'
* Sat Dec 12 2015 cloud-devel@suse.de
- Update to version ironic-4.3.1.dev42:
  * Fix iPXE template for whole disk image
  * Add devstack plugin
* Fri Dec 11 2015 tbechtold@suse.com
- Update to version ironic-4.3.1.dev38:
  * Copy devstack code to ironic tree
  * Add oslo_config.Opt support in Ironic config generator
* Fri Dec 11 2015 cloud-devel@suse.de
- Update to version ironic-4.3.1.dev34:
  * Follow up patch to correct code-contribute-guide
  * Explicitly depend on WebTest>=2.0
  * Always pass keystone credentials to neutronclient
  * Correct NotImplemented to NotImplementedError in rpcapi.py
* Thu Dec 10 2015 cloud-devel@suse.de
- Update to version ironic-4.3.1.dev26:
  * Use node.uuid directly in stop_console()
  * Adding oneview.common tests for some method not well tested
  * Add port option support for ipmitool
  * Numerous debug messages due to iso8601 log level
  * Handle deprecated opts' group correctly
  * Clarify what changes need a release note
  * Add Mitaka release notes page
  * Update python-scciclient version number
* Wed Dec  9 2015 cloud-devel@suse.de
- Update to version ironic-4.3.1.dev10:
  * Updated from global requirements
  * Remove wsgi reset_pool_size_to_default test
* Tue Dec  8 2015 cloud-devel@suse.de
- Update to version ironic-4.3.1.dev8:
  * Add release notes from Icehouse to Liberty
  * Add Code Contribution Guide for Ironic
  * Replace HTTP 'magic numbers' with constants
  * Documentation points to official release notes
  4.3.0
  * Split BaseConductorManager from ConductorManager
* Sat Dec  5 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev352:
  * Fix awake AMT unit test
  * Fix bug where clean steps do not run
  * Correct the db connection string in dev-quickstart
* Fri Dec  4 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev347:
  * Add reno for AMT wakeup patch
  * Updating OneView driver requirements and docs
  * change mysql url in dev-quickstart doc
* Thu Dec  3 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev342:
  * test: Remove _BaseTestCase
  * Wake up AMT interface before send request
  * Sync ironic.conf sample
* Wed Dec  2 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev336:
  * Fall back to old boot.ipxe behaviour if inc command is not found
  * Only mention IPA in the quick start and user guides for DevStack
  * Improve options help for image caching
  * Add troubleshooting docs for "no valid host found"
  * Extend FAQ with answer of how to create a new release note
* Tue Dec  1 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev326:
  * Add tests for RequestContextSerializer
  * Add a test to enforce object version bump correctly
  * force releasenotes warnings to be treated as errors
* Mon Nov 30 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev320:
  * Comment spelling error in ironic-images.filters file
  * Updated from global requirements
  * Add a developer FAQ
  * Follow up patch for the first commit of iRMC new boot I/F
* Sat Nov 28 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev313:
  * Avoid RequestContextSerializer from oslo.messaging
* Fri Nov 27 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev311:
  * Move iso8601 as a test dependency only
  * Catch up release notes for Mitaka
  * Add deprecated config info in ironic.conf.sample
* Thu Nov 26 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev306:
  * Move common code from ironic.conductor.manager to ironic.conductor.utils
* Thu Nov 26 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev304:
  * Add switch to enable/disable streaming raw images for IPA
  * SwiftAPI constructor should read CONF variables at runtime
  * Take over console session if enabled
  * Refactor IRMCVirtualMediaAgentDeploy by applying new BootInterface
  * Check shellinabox started successfully or not
  * Add SSL support to the Ironic API
  * Refactor agent_ilo driver to use new boot interface
  * Refactor iLO driver console interface into new module
  * refine the ironic installation guide
* Wed Nov 25 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev286:
  * Drop some outdated information from our quick start guide
  * Refactor IRMCVirtualMediaIscsiDeploy by applying new BootInterface
* Tue Nov 24 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev282:
  * Updated from global requirements
  * Fix: Next cleaning hangs if the previous cleaning was aborted
  * Add clean up method for the DHCP factory
  * Add missing packages to dev-quickstart
  * Get mandatory patch attrs from WSME properties
  * Update iLO documentation
  * Adds test case for the iscsi_ilo recreate boot iso
  * Fix comments on DRAC BIOS vendor_passthru
* Sun Nov 22 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev266:
  * Add manual cleaning to state machine
* Sat Nov 21 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev264:
  * Specifying target provision states in fsm
  * Use server_profile_template_uri at scheduling
* Fri Nov 20 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev260:
  * Support arguments for clean step methods
  * Validate all tcp/udp port numbers
* Thu Nov 19 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev256:
  * Updated from global requirements
  * Use wsgi from oslo.service for Ironic API
  * Remove duplicated unit tests in test_manager
  * Add and document two new root device hints: wwn_{with, vendor}_extension
  * Sort root device hints when parsing
  * Document 'erase_devices_iterations' config option
* Wed Nov 18 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev244:
  * add "unreleased" release notes page
  * Follow up patch for 39e40ef12b016a1aeb37a3fe755b9978d3f9934f
  * Remove __name__ attribute from WSME user types
* Tue Nov 17 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev238:
  * Updated from global requirements
  * Add reno for release notes management
  * Add choices to temp_url_endpoint_type config option
  * Fix docker.io bug in the Install Guide
* Sat Nov 14 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev231:
  * Fix oslo namespace in default log level
  * Revert "Add Pillow to test-requirements.txt"
  * Update etc/ironic/ironic.conf.sample
  * Make task parameter mandatory in get_supported_boot_devices
  * Follow up patch for Ib8968418a1835a4131f2f22fb3e4df5ecb9b0dc5
* Fri Nov 13 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev221:
  * Check shellinabox process during stopping console
* Thu Nov 12 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev219:
  * Add whole disk image creation command to Installation Guide
  * Updated from global requirements
  * Node's last_error to show the actual error from sync_power_state
  * Updated from global requirements
  * Rename test_conductor_utils.py to test_utils.py
  * Follow up patch for 8c3e102fc5736bfcf98525ebab59b6598a69b428
  * Add agent_iboot entrypoint
  * Validate console port number in a valid range
  * iboot: add wait loop for pstate to activate
  * Validate the input of properties of nodes
  * Add documentation for Ceph Object Gateway support
  * Refactor iscsi_ilo driver to use new boot interface
  * Added unit tests for CORS middleware
* Tue Nov 10 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev195:
  * Don't reraise the exception in _set_console_mode
  * Check seamicro terminal port as long as it specified
  * Add missing unit tests for some PXE drivers
  * cautiously fail on unhandled heartbeat exception
* Sat Nov  7 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev187:
  * Use oslo_config new type PortOpt for port options
  * Add PortOpt to config generator
  * Expose versioning information on GET / endpoint
* Wed Nov  4 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev181:
  * Add "agent_wol" (AgentAndWakeOnLanDriver)
  * Rename utils.py to mgr_utils.py to avoid namespace collision
* Tue Nov  3 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev177:
  * Add self.raid for iSCSI based drivers
* Fri Oct 30 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev175:
  * Fix markup error in deploy/drivers.rst
* Thu Oct 29 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev173:
  * Update the Configuration Reference to Liberty in doc
  * iPXE document about the existence of prebuilt images
* Tue Oct 27 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev169:
  * Updated from global requirements
  * XenAPI: Add support for XenServer VMs
* Sat Oct 24 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev165:
  * Use self.__class__.X instead of self.X
* Fri Oct 23 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev163:
  * Imported Translations from Zanata
  * Move hash_ring refresh logic out of sync_local_state
  * Move ironic.tests.unit.base to ironic.tests.base
  * Switched order of CORS middleware
  * DRAC BIOS vendor_passthru: enable rebooting the node
  * Add db migration and model for tags table
* Thu Oct 22 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev152:
  * Change required version of ImcSdk to 0.7.2
  * Add an iboot reboot_delay setting
  * Fix a typo
  * Replace deprecated LOG.warn with warning
* Tue Oct 20 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev145:
  * Add OneView driver documentation
  * Fix snmp property descriptions
  * Updated from global requirements
  * Remove unused functions from agent driver
  * mocking syscalls to make the tests run on OS X
  * Enable cmd/api & cmd/conductor to be launched directly
* Tue Oct 20 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev133:
  * Slightly reword README
  * Add reboot_delay option to snmp driver
* Sat Oct 17 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev130:
  * Move test_pxe.py inside unit/drivers/modules directory
  * Move pxe._parse_instance_info() to deploy_utils
  * Enable radosgw support in ironic
* Fri Oct 16 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev124:
  * Add note about driver API breakage
  * Fix a missing detail in install guide
  * Updated from global requirements
  * Add agent_amt docs
* Thu Oct 15 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev117:
  * Add release notes for 4.2.1
  * Convert set() to list in ListType
  * remove lxml requirement
  * Update python-oneviewclient version
  * Add support for in-band cleaning in ISCSIDeploy
  * Refactor deploy_utils methods
* Thu Oct 15 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev105:
  * Fix an annoying detail in the developer quick-start
  * Fixes logging of failure in deletion of swift temporary object
  * ucs_hostname changed to ucs_address
  * Updated from global requirements
  * Remove functions: _cleanse_dict & format_message
  * Move FakeOneViewDriver to the fake.py module
* Wed Oct 14 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev93:
  * Updated from global requirements
  * OneView Driver for Ironic
* Tue Oct 13 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev90:
  * Add testresources and testscenarios used by oslo.db fixture
  * Add agent_amt driver
* Mon Oct 12 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev87:
  * Imported Translations from Zanata
  * Stop adding translation function to builtins
  * Fix tests giving erroneous output during os-testr run
  * Fix agent_ilo to remove temporary images
  * Prevent iRMC unit test from potential failure at the gate
* Sat Oct 10 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev78:
  * Updated from global requirements
  * iPXE: Fix assumption that ${mac} is the MAC of the NIC it's booting
  * Add secret=True to password option
  * Fix a bug error by passwords only includes numbers
  * PXE: Support Extra DHCP Options for IPv6
* Fri Oct  9 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev69:
  * Fix typo in document
  * Remove unused import of oslo_log
  * Use power manager to reboot in agent deployments
  * Add retries to ssh._get_hosts_name_for_node
  * Fix irmc driver unit test
* Thu Oct  8 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev59:
  * Use standard locale when executing 'parted' command
  * To run a specific unit test with ostestr use -r
  * Add .eggs to gitignore
  * Fix log formatting issue in agent base
  * Add notes to functions which are in ironic-lib
  * Allow empty password for ipmitool console
  * Update help string on tftp_root option
  * Updated from global requirements
  * Fix conductor deregistration on non init conductor
  * Rename 'message' attribute to '_msg_fmt' in IronicException
* Mon Oct  5 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev39:
  * Add agent inspection support for IPMI and SSH drivers
  * Move unit tests to correct directory
* Sat Oct  3 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev35:
  * Updated from global requirements
  * Imported Translations from Zanata
  * Add Pillow to test-requirements.txt
* Fri Oct  2 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev30:
  * Python 3.4 unit tests fail with LANG=C
  * Fix ubuntu install command in install guide
  * Follow up for: Prepare for functional testing patch
  * Use standard locale when executing 'dd' command
* Wed Sep 30 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev22:
  * Add 'whitelist_externals = bash' for two testenvs
  * Fix documentation for installing mariaDB
  * Update help strings for DRAC configs
  * Fix some iBoot strings
* Tue Sep 29 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev14:
  * Switch tox unit test command to use ostestr
  * Imported Translations from Zanata
  * Fix typo: add a missing white space
  * Prepare for functional testing
  * Replace six.iteritems() with .items()
* Mon Sep 28 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev5:
  * Fix string formatting issues
* Sat Sep 26 2015 cloud-devel@suse.de
- Update to version ironic-4.2.1.dev4:
  * Make generation of ironic.conf.sample deterministic
  * Cached file should not be deleted if time equal to master
  4.2.0
  * Cleanup of Translations
  * Update architecture docs to mention new driver interfaces
  * Add 4.2.0 release notes
  * Update docs for Fedora 22
  * Add i18n _ import to cimc common
  * Update proliantutils version required for L release
  * Use of 'the Bare Metal service' in guide
  * Update install guide to reflect latest code
  * Implement indirection_api
  * Add 'abort' to state machine diagram
  * Unit test environment setup clarification
* Thu Sep 24 2015 cloud-devel@suse.de
- Update to version ironic-4.1.1.dev86:
  * Make end-points discoverable via Ironic API
* Wed Sep 23 2015 cloud-devel@suse.de
- Update to version ironic-4.1.1.dev84:
  * Updated from global requirements
  * Allow unsetting node.target_raid_config
  * Allow abort for CLEANWAIT states
  * Clean up CIMC driver docs and comments
  * Add Cisco IMC PXE Driver
* Tue Sep 22 2015 cloud-devel@suse.de
- Update to version ironic-4.1.1.dev75:
  * Fix final comments in RAID commits
  * Refactor agent {prepare,tear_down}_cleaning into deploy_utils
  * Handle unquoted node names from virt types
  * Fix iRMC vmedia deploy failure due to already attached image
  * Implement take_over for iscsi_ilo driver
* Mon Sep 21 2015 cloud-devel@suse.de
- Update to version ironic-4.1.1.dev66:
  * Remove unused object function
* Sun Sep 20 2015 cloud-devel@suse.de
- Update to version ironic-4.1.1.dev64:
  * Fix typo in vendor method dev documentation
  * Add constraint target to tox.ini
  * Add IPMINative vendor methods to *IPMINative drivers
  * Convert functools.wraps() usage to six.wraps()
* Sat Sep 19 2015 cloud-devel@suse.de
- Update to version ironic-4.1.1.dev56:
  * Fix incorrect urls
  * Check image size before provisioning for agent driver
  * Help patch authors to remember to update version docs
  * Remove DictMatches custom matcher from unit tests
  * Imported Translations from Zanata
  * Update descriptions in RAID config schema
  * Document GET ...raid/logical_disk_properties
* Fri Sep 18 2015 cloud-devel@suse.de
- Update to version ironic-4.1.1.dev42:
  * Use oslo.versionedobjects remotable decorators
  * Base IronicObject on VersionedObject
* Thu Sep 17 2015 cloud-devel@suse.de
- Update to version ironic-4.1.1.dev38:
  * Remove comment about exception decorator
  * Replace metaclass registry with explicit opt-in registry from oslo
  * Add config option to override url for links
  * Allow tftpd usage of '--secure' by using symlinks
  * Add support for inband raid configuration agent ramdisk
* Wed Sep 16 2015 cloud-devel@suse.de
- Update to version ironic-4.1.1.dev28:
  * Fix iBoot test__switch_retries test to not waste time sleeping
  * Agent supports post-clean-step operations
  * Update 'Installation Guide' for RHEL7/CentOS7/Fedora
* Tue Sep 15 2015 cloud-devel@suse.de
- Update to version ironic-4.1.1.dev23:
  * Fix docs about --is-public parameter for glance image-create
  * Fix indentation of the console docs
  * Fix heading levels in the install-guide
* Sat Sep 12 2015 cloud-devel@suse.de
- Update to version ironic-4.1.1.dev17:
  * Cache the description of RAID properties
  * Trusted boot doc
* Fri Sep 11 2015 cloud-devel@suse.de
- Update to version ironic-4.1.1.dev14:
  * Remove the hard dependency of swift from ilo drivers
  * Fix mistakes in comments
  * Updated from global requirements
  * Fix object field type calling conventions
  * When boot option is not persisted, set boot on next power on
* Thu Sep 10 2015 cloud-devel@suse.de
- Update to version ironic-4.1.1.dev5:
  * Add version info for pyghmi in driver-requirements.txt
  4.1.0
  * Add description how to restart ironic services in Fedora/RHEL7/CentOS7
  * Add APIs for RAID configuration
  * Add retry options to iBoot power driver
  * Use vendor mixin in IPMITool drivers
* Wed Sep  9 2015 cloud-devel@suse.de
- Update to version ironic-4.0.1.dev102:
  * Add 4.1.0 release notes
  * Try to standardize retrieval of an Exception's description
  * Improve the ability to resolve capability value
  * Add supported environment 'VMware' to comments
  * Updated from global requirements
  * Remove policy 'admin' rule support
  * Handle missing is_whole_disk_image in pxe._build_pxe_config_options
  * Raise InvalidPrameterValue when ipmi_terminal_port is ''
  * Remove executable permission from irmc.py
  * Add vendor interface to ipminative driver
  * Use oslo.messaging serializers
* Tue Sep  8 2015 cloud-devel@suse.de
- Update to version ironic-4.0.1.dev81:
  * Fix doc typo
* Mon Sep  7 2015 cloud-devel@suse.de
- Update to version ironic-4.0.1.dev80:
  * Document nodes in enroll state, in install guide
* Sun Sep  6 2015 cloud-devel@suse.de
- Update to version ironic-4.0.1.dev78:
  * Set boot device in PXE Boot interface method prepare_instance()
* Fri Sep  4 2015 cloud-devel@suse.de
- Update to version ironic-4.0.1.dev76:
  * agent_ilo fails to bring up instance
  * Updated from global requirements
  * Remove 'is_valid_event' method
  * Revert "Do not overwrite the iPXE boot script on every deployment"
  * Removes unused posix-ipc requirement
  * Prevent ilo drivers powering off active nodes during take over
  * Fix docker package name in Ubuntu 14.04 in Install Guide
  * Remove unused dep discover from test reqs
  * Add deprecation warning to periodic tasks with parallel=False
* Thu Sep  3 2015 cloud-devel@suse.de
- Update to version ironic-4.0.1.dev58:
  * Added CORS support middleware to Ironic
  * Refactor map_color()
  * Add release notes for 4.0.0
  * Clean up cleaning error handling on heartbeats
  * Add RPC APIs for RAID configuration
  * Reset tempdir config option after NestedTempfile fixture applied
  * Use six.text_type in parse_image_ref
* Wed Sep  2 2015 cloud-devel@suse.de
- Update to version ironic-4.0.1.dev44:
  * Add new method validate_raid_config to RAIDInterface
* Tue Sep  1 2015 cloud-devel@suse.de
- Update to version ironic-4.0.1.dev42:
  * Updated from global requirements
  * Do not overwrite the iPXE boot script on every deployment
  * Add minimum and maximum on port option
  * Use automaton's converters/pydot
* Mon Aug 31 2015 cloud-devel@suse.de
- Update to version ironic-4.0.1.dev35:
  * Fix minor spelling/grammar errors
* Sun Aug 30 2015 cloud-devel@suse.de
- Update to version ironic-4.0.1.dev33:
  * Ensure that pass_deploy_info() always calls boot.prepare_instance()
  * Update ironic.conf.sample with tox -egenconfig
  * Update documentation to install grub2 when creating the user image
  * Periodically checks for nodes being cleaned
  * Refactor agent driver with pxe boot interface
  * Improve comparison operators for api/controllers/base.py
* Sat Aug 29 2015 cloud-devel@suse.de
- Update to version ironic-4.0.1.dev21:
  * Fix logging and exceptions messages in ipminative driver
  * Put py34 first in the env order of tox
* Fri Aug 28 2015 cloud-devel@suse.de
- Update to version ironic-4.0.1.dev17:
  * format links in the readme to work with the release notes tools
  * Add links for UEFI secure boot support to iLO driver documentation
  * Remove broken workaround code for old mock
  * Use JsonEncoded{Dict,List} from oslo_db
* Thu Aug 27 2015 cloud-devel@suse.de
- Update to version ironic-4.0.1.dev10:
  * Add cleanup in console utils tests
  * Follow up the nits in iRMC vmedia driver merged patch
  * Update tests to reflect WSME 0.8 fixes
  * Create a versions.py file
* Wed Aug 26 2015 cloud-devel@suse.de
- Update to version ironic-4.0.1.dev3:
  * Remove ObjectListBase
  * Switch to post-versioning
  4.0.0
* Tue Aug 25 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev563:
  * Fix improper exception catching
  * Fix nits from 'HTTP constants' patch
* Mon Aug 24 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev559:
  * Move tests into correct directories
  * Fix logging levels in do_node_deploy
* Sun Aug 23 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev555:
  * Fix misspelling from "applicatin" to "application"
  * Remove unneeded module variable '__all__'
  * Reset clean_step if error occurs in CLEANWAIT
* Sat Aug 22 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev549:
  * Updated from global requirements
  * Updated from global requirements
  * Change and edit of Ironic Installation Guide
  * Switch from deprecated timeutils.isotime
  * Fix "tox -egenconfig" by avoiding the MODULEPATH env variable
  * Improve logging for agent driver
  * Replace HTTP 'magic numbers' with constants
* Fri Aug 21 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev535:
  * Remove the --autofree option from boot.ipxe
  * Refactor the essential prop list of inspect driver
  * Fix bug sending sensor data for drivers w/o management
  * Address final comments on update image cache based on update time
  * 'updated_at' field shows old value after resource is saved
  * Increase size of nodes.driver column
  * Add better dbapi support for querying reservation
* Wed Aug 19 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev521:
  * Add copyright notice to iRMC driver source code
* Tue Aug 18 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev519:
  * Update cached images based on update time
* Sat Aug 15 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev517:
  * Allow digits in IPA driver names
  * Updated from global requirements
  * Add documentation for iRMC virtual media driver
  * Remove CONF.agent.agent_pxe_bootfile_name
  * Update single letter release names to full names
  * Enforce flake8 E711
  * Update docstring for agent deploy's take_over
  * Updated from global requirements
  * Add RAIDInterface for RAID configuration
  * get_supported_boot_devices() returns static device list
  * add ironic client and ironic inspector projects into contribution list
  * Updated from global requirements
  * Use the oslo_utils.timeutils 'StopWatch' class
  * Update the documentation to use IPA as deploy ramdisk
  * Inspector inspection fails due to node locked error
  * Prevent power actions when the node is in CLENWAIT state
  * Imported Translations from Transifex
  * Remove unnecessary trailing backslash in Installation Guide
  * Refactor some minor issues to improve code readability
  * Fix misspelling in comment
  * Make app.wsgi more like ironic.cmd.api
  * Migrate IronicObjectSerializer to subclass from oslo
  * Updated from global requirements
  * Change vagrant.yml to vagrant.yaml
  * Developer quickstart documentation fixes
* Tue Aug 11 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev468:
  * Fix warnings on doc builds
* Fri Aug  7 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev467:
  * Document configuring ironic-api behind mod_wsgi
* Thu Aug  6 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev465:
  * Updated from global requirements
  * Add deprecation messages on the bash ramdisk endpoints
  * Document API versioning
  * Log configuration values as DEBUG, not INFO
  * Clean up instance_uuid as part of the node's tear down
  * Fix a trusted boot test bug
  * Secure boot support for pxe_ilo driver
  * Vagrant configuration generation now uses pymysql
* Wed Aug  5 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev449:
  * grub2 bootloader support for uefi boot mode
* Tue Aug  4 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev447:
  * Update ironic.conf.sample
  * Update ironic.conf.sample
  * Only take exclusive lock in sync_power_state if node is updated
  * Save and re-raise exception
* Sun Aug  2 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev439:
  * Add raises docstring tag into object.Ports methods
* Sat Aug  1 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev437:
  * Add information 'node_uuid' in debug logs to facilitate the reader's life
  * Add more info level log to deploy_utils.work_on_disk() method
  * Fix broken agent virtual media drivers
  * Updated from global requirements
  * UCS: node-get-boot-device is failing for Cisco servers
  * Add Nova scheduler_tracks_instance_changes config to docs
  * enroll/verify/cleanwait in state machine diagram
  * Cache Keystone client instance
  * Introduce support for APC MasterSwitchPlus and Rack PDU
* Fri Jul 31 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev419:
  * Fix apache wsgi import
* Thu Jul 30 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev418:
  * Refactor pxe - New PXEBoot and ISCSIDeploy interfaces
  * Don't prevent updates if power transition is in progress
  * Follow-on to b6ed09e297 to fix docstrings/comments
  * Make inspector driver test correctly
  * Allow inspector driver to work in standalone mode
  * Remove outdated TODO.rst file
  * Updated from global requirements
* Wed Jul 29 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev405:
  * Allow agent lookup to directly accept node UUID
  * Add CLEANWAIT state
  * Allow updates in VERIFYING state
* Tue Jul 28 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev400:
  * Allow deleting nodes in ENROLL state
  * Updated from global requirements
* Sun Jul 26 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev397:
  * Add IPA support for iscsi_irmc driver
* Sat Jul 25 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev395:
  * Fixes a testcase related to trusted boot in UEFI boot mode
  * Clarify inspection upgrade guide
  * Refactor refresh method in objects for reuse
  * Imported Translations from Transifex
  * Updated from global requirements
  * Move the http_url and http_root to deploy config
* Fri Jul 24 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev383:
  * Use utils.mkfs directly in deploy_utils
  * Migrate ObjectListBase to subclass from the Oslo one
  * Clean up tftp files if agent deployed disk image
  * Don't do a premature reservation check in the provision API
  * Fix the DEPLOYWAIT check for agent_* drivers
* Wed Jul 22 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev373:
  * Allow upgrading shared lock to an exclusive one
  * Add a missing comma in Vendor Methods of Developer Guide
  * Replacing dict.iteritems() with dict.items()
  * Address minor comments on the ENROLL patch
* Sun Jul 19 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev366:
  * Updated from global requirements
  * db: use new EngineFacade feature of oslo.db
  * Remove requirements.txt from tox.ini deps
  * Updated from global requirements
  * Replace common.fileutils with oslo_utils.fileutils
  * Updated from global requirements
  * Switch to the oslo_utils.fileutils
  * Start using new ENROLL state
  * Add .idea to .gitignore
  * Periodically checks the status of nodes in DEPLOYING state
  * Updated from global requirements
  * Remove deprecated code for driver vendor passthru
  * Add DRAC BIOS config vendor passthru API
  * Use DEPLOYWAIT while waiting for agent to write image
  * Fix unittests due mock 1.1.0 release
  * Migrate RPC objects to oslo.versionedobjects Fields
  * Imported Translations from Transifex
  * Updated from global requirements
  * Mock the file creation for the GetConfigdriveTestCase tests
  * Address follow-up comments
  * Clear ilo_boot_iso before deploy for glance images
  * Enable translation for config option help messages
  * Replace is_hostname_safe with a better check
  * Initial oslo.versionedobjects conversion
  * Add whole disk image support for iscsi_irmc driver
  * Add localboot support for iscsi_irmc driver
  * Add iRMC Virtual Media Deploy module for iRMC Driver
  * add python-scciclient version number requirement
  * Remove db connection string env variable from tox.ini
  * Make use of tempdir configuration
* Tue Jun 23 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev246:
  * Use LOGDIR instead of SCREEN_LOGDIR in docs
  * Always allow removing instance_uuid from node in maintenance mode
  * API: Get a subset of fields from Nodes
  * Switch from MySQL-python to PyMySQL
  * Add option to configure passes in erase_devices
* Mon Jun 22 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev237:
  * Updated from global requirements
  * Finish switch to inspector and inspector-client
  * Rename ilo_power._attach_boot_iso to improve readability
  * Refactor node's and driver's vendor passthru to a common place
  * Add disk layout check on re-provisioning
* Fri Jun 19 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev228:
  * Expose current clean step in the API
  * Change return value of [driver_]vendor_passthru to dict
* Thu Jun 18 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev224:
  * Fix broken ACL tests
  * Add Wake-On-Lan driver documentation
  * Added documentation to Vagrantfile
  * Updated from global requirements
  * Validate capability in properties and instance_info
  * Enable flake8 checking of ironic/nova/*
* Thu Jun 18 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev213:
  * Fixes a bug on the iLO driver tutorial
  * Address follow-up comments on ucs drivers
  * Fix Cisco UCS slow tests
* Wed Jun 17 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev208:
  * Addresses UcsSdk install issue
  * Don't raise exception from set_failed_state()
  * Add boot interface in Ironic
* Tue Jun 16 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev203:
  * Remove tools/flakes.py
* Mon Jun 15 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev201:
  * Pass environment variables of proxy to tox
  * DRAC: fix set/get boot device for 11g
  * IPA: Do a soft power off at the end of deployment
* Sun Jun 14 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev195:
  * Wake-On-Lan Power interface
  * Remove unnecessary validation in PXE
  * Add additional logging around cleaning
  * remove unneeded sqlalchemy-migrate requirement
  * Add vendor-passthru to attach and boot an ISO
* Thu Jun 11 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev186:
  * Updated from global requirements
  * Sync with latest oslo-incubator
  * Add pxe_ucs and agent_ucs drivers to manage Cisco UCS servers
  * Doc: Use --notest for creating venv
  * Updated from global requirements
  * Fix DRAC driver job completion detection
  * Add additional required RPMs to dev instructions
  * Update docs for usage of python-ironicclient
  * Install guide reflects changes on master branch
  * Remove auth token saving from iLO driver
  * Don't support deprecated drivers' vendor_passthru
  * Updated from global requirements
  2015.1.0
  * Updated from global requirements
  * Release Import of Translations from Transifex
  * Remove scripts for migrating nova baremetal
  * update .gitreview for stable/kilo
  * Fix heartbeat when clean step in progress
  2014.2
  * Add the PXE VendorPassthru interface to PXEDracDriver
* Fri Jun  5 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev197:
  * Enforce flake8 E123/6/7/8 in ironic
  * Change driver_info to driver_internal_info in conductor
  * Use svg as it looks better/scales better than png
  * Updated from global requirements
  * Use oslo config import methods for Keystone options
* Thu Jun  4 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev188:
  * Add documentation for getting a node's console
  * fix node-get-console returns url always start with http
  * Update the config drive doc to replace deprecated value
  * Remove bogus conditional from node_update
  * Prevent node delete based on provision, not power, state
  * Revert "Add simplegeneric to py34 requirements"
  * Do not save auth token on TFTP server in PXE driver
  * Updated from global requirements
  * Update iLO documentation for UEFI secure boot
* Wed Jun  3 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev170:
  * Updated from global requirements
  * ironic-discoverd is being renamed to ironic-inspector
  * Improve strictness of iLO test cases error checking
* Tue Jun  2 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev164:
  * Update doc "install from packages" section to include Red Hat
  * Remove deprecated pxe_deploy_{kernel, ramdisk}
* Fri May 29 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev161:
  * Get admin auth token for Glance client in image_service
* Thu May 28 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev159:
  * Fix: iSCSI iqn name RFC violation
  * Update documentation index.rst
  * Update AMT Driver doc
  * Refactor ilo.common._prepare_floppy_image()
* Wed May 27 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev152:
  * Do not add auth token in context for noauth API mode
  * Disable meaningless sort keys in list command
  * Update pyremotevbox documentation
  * Delete neutron ports when the node cleaning fails
* Tue May 26 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev144:
  * DRAC: config options for retry values
* Sat May 23 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev142:
  * Update to hacking 0.10.x
  * Slight changes to Vagrant developer configs
* Fri May 22 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev138:
  * Fix drac implementation of set_boot_device
  * Prepare for hacking 0.10.x
  * Rename gendocs tox environment
  * Fixes some docstring warnings
  * Added vagrant VM for developer use
* Wed May 20 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev128:
  * Add simplegeneric to py34 requirements
* Mon May 18 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev127:
  * Reduce AMT Driver's dependence on new release of Openwsman
  * Fix chainloading iPXE (undionly.kpxe)
* Fri May 15 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev124:
  * Update docstring DHCPNotFound -> DHCPLoadError
  * Ironic doesn't use cacert while talking to Swift
  * Improve strictness of AMT test cases error checking
* Thu May 14 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev118:
  * Wrap all DHCP provider load errors
  * Add partition number to list_partitions() output fields
  * Execute "parted" from root in list_partitions()
  * Remove unused CONF variable in test_ipminative.py
  * Improve root partition size check in deploy_partition_image
* Wed May 13 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev109:
  * Updated from global requirements
* Tue May 12 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev108:
  * Improve strictness of iRMC test cases error checking
* Mon May 11 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev106:
  * ironic/tests/drivers: Add autospec=True and spec_set=
  * Fix and enhance "Exercising the Services Locally" docs
  * Fix typos in Ironic docs
  * Fix spelling error in docstring
  * Check temp dir is usable for ipmitool driver
* Sat May  9 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev96:
  * Remove deprecated exceptions
* Thu May  7 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev95:
  * Fix Python 3.4 test failure
  * Remove unneeded usage of '# noqa'
  * Add section header to state machines page
  * Remove cleanfail->cleaning from state diagram
* Thu May  7 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev87:
  * Drop use of 'oslo' namespace package
  * Updated from global requirements
  * Specify environment variables needed for a standalone usage
  * Adds OCS Power and Management interfaces
  * Run tests in py34 environment
  * Update config generator to use oslo released libs
* Wed May  6 2015 tbechtold@suse.com
- Update to version ironic-2015.2.0.dev75:
  * Adds docstrings to some functions in ironic/conductor/manager.py
  * Use oslo_log lib
  * Include graphviz in install prerequisites
  * Link to config reference in our docs
  * Return HTTP 400 for invalid sort_key
* Wed May  6 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev65:
  * Imported Translations from Transifex
* Tue May  5 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.0.dev63:
  * Adopt config generator
* Mon May  4 2015 vuntz@suse.com
- Update to version ironic-2015.2.dev64:
  * Update the Vendor Passthru documentation
  * Add maintenance mode example with reason
  * Add logical name example to install-guide
  * Improve strictness of DRAC test cases error checking
  * Add a venv that can generate/write/update the states diagram
  * Log attempts while trying to sync power state
  * Disable clean_step if config option is set to 0
  * Improve iSCSI deployment logs
  * supports alembic migration for db2
  * Updated from global requirements
  * Update iLO documentation for capabilities
  * ironic/tests/drivers/amt: Add autospec=True to mocks
  * ironic/tests/drivers/irmc: Add spec_set & autospec=True
  * ironic/tests/drivers/drac: Add spec_set= or autospec=True
  * Create a 3rd party mock specs file
  * Document how to configure Neutron with iPXE
  * Remove state transition: CLEANFAIL -> CLEANING
  * Add a missing comma and correct some typos
  * Remove API reboot from cleaning docs
  * Remove scripts for migrating nova baremetal
  * Remove ironic compute driver and sched manager
  * Update some config option's help strings
* Tue Apr 21 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.dev23:
  * Fixed is_glance_image(image_href) predicate logic
  * Rearrange some code in PXEDeploy.prepare
  * Add cleaning network docs
* Sat Apr 18 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.dev17:
  * Fixes typo in ironic/api/hooks.py and removes unnecessary parenthesis
  * ironic/tests/drivers/ilo: Add spec= & autospec=True to mocks
* Thu Apr 16 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.dev13:
  * Replace 'metrics' with 'meters' in option
  * document "scheduler_use_baremetal_filters" option in nova.conf
  * Fix heartbeat when clean step in progress
  * Update ilo drivers documentation for inspection
  2015.1.0rc1
* Tue Apr 14 2015 cloud-devel@suse.de
- Update to version ironic-2015.2.dev198:
  * Open Liberty development
  * Local boot note about updated deploy ramdisk
  * Fix typos in vendor-passthru.rst
  * Update session headers during initialization of AgentClient
  * Cleanup DHCPFactory._dhcp_provider after tests
* Mon Apr 13 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev188:
  * Convert internal RPC continue_node_cleaning to a "cast"
  * iLO driver documentation for node cleaning
  * Add Ceilometer to Ironic's Conceptual Architecture
  * Improve AMT driver doc
  * iLO driver documentation for UEFI secure boot
  * Use mock patch decorator for eventlet.greenthread.sleep
  * Fix type of value in error middleware response header
* Fri Apr 10 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev174:
  * Fix for automated boot iso issue with IPA ramdisk
  * Agent driver fails without Ironic-managed TFTP
  * Add notes about upgrading juno->kilo to docs
  * Nit fixes for boot_mode being overwritten
  * Update installation service overview
* Thu Apr  9 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev165:
  * Address comments on I5cc41932acd75cf5e9e5b626285331f97126932e
  * Follow-up to "Add retry logic to _exec_ipmitool"
  * Don't pass boot_option: local for whole disk images
  * Use hexhyp instead of hexraw iPXE type
* Wed Apr  8 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev157:
  * Fixup post-merge comments on cleaning document
  * Fix exception handling in Glance image service
  * Update proliantutils version required for K release
  * Imported Translations from Transifex
  * Fix mocks not being stopped as intended
  * Add maintenance check before call do_node_deploy
  * Fix VM stuck when deploying with pxe_ssh + local boot
  * Fix bad quoting in quickstart guide
  * Set hash seed to 0 in gendocs environment
  * boot_mode is overwritten in node properties
  * Add retry logic to _exec_ipmitool
  * Shorten time for unittest test_download_with_retries
  * tests/db: Add autospec=True to mocks
  * Sync with oslo.incubator
  * Update doc for test database migrations
* Tue Apr  7 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev127:
  * Check status of bootloader installation for DIB ramdisk
  * Add missing mock for test_create_cleaning_ports_fail
  * Fix help string for glance auth_strategy option
  * Document ports creating configuration for in-band inspection
  * Refactor test code to reduce duplication
* Mon Apr  6 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev117:
  * Disable XML now that we have WSME/Pecan support
  * Add missing test for DB migration 2fb93ffd2af1
* Sat Apr  4 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev114:
  * Remove DB tests workarounds
  * Fix formatting issue in install guide
* Fri Apr  3 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev110:
  * Enable cleaning by default
  * Improve error handling when JSON is not returned by agent
  * Fix is_hostname_safe for RFC compliance
* Thu Apr  2 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev104:
  * Regenerate states diagram after addition of CLEANING
  * Fix UnicodeEncodeError issue when the language is not en_US
  * pxe deploy fails for whole disk images in UEFI
  * Remove setting language to en_US for 'venv'
  * Add config drive documentation
  * Mock time.sleep() for two unittests
  * Add display-name option to example apache2 configuration
  * New field 'name' not supported in port REST API
  * Top level unit tests: Use autospec=True for mocks
  * Add whole disk image support for iscsi_ilo using agent ramdisk
* Wed Apr  1 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev86:
  * Clarify message for power action during cleaning
  * Add PXE-AMT driver's support of IPA ramdisk
  * Fix cleaning nits
  * Update docs: No power actions during cleaning
  * Prevent power actions on node in cleaning
  * Followup to comments on Cleaning Docs
  * Remove inspect_ports from ilo inspection
  * Enable pxe_amt driver with localboot
  * Improve backwards compat on API behaviour
* Tue Mar 31 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev69:
  * Removed hardcoded IDs from "chassis" test resources
  * Use node UUID in logs instead of node ID
  * Add IPA to enable drivers doc's page
  * Add documentation for Cleaning
  * Prevent updating the node's driver if console is enabled
  * Ensure configdrive isn't mounted for ilo drivers
  * DRAC: add retry capability to wsman client operations
* Mon Mar 30 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev55:
  * DRAC: power on during reboot if powered off
  * Update pythonseamicroclient package version
  * A wrong variable format used in msg of ilo:
  * Explictly state that reboot is expected to work with powered off nodes
  * Add local boot with partition images documentation
* Sat Mar 28 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev46:
  * Agent driver: no-op heartbeat for maintenanced node
  * Attach ilo_boot_iso only if node is active
  * Ensure configdrive isn't mounted for ipxe/elilo
* Fri Mar 27 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev40:
  * Deploys post whole disk image deploy fails
  * Allow node.instance_uuid to be removed during cleaning
  * Correct update_dhcp_opts methods
* Thu Mar 26 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev34:
  * Add root device hints documentation
  * Add a return after saving node power state
* Wed Mar 25 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev30:
  * Fix broken unittests usage of sort()
  * Ensure configdrive isn't mounted in CoreOS ramdisks
  * Fix formatting error in states_to_dot
  * Raise exception for Agent Deploy driver when using partition images
* Tue Mar 24 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev22:
  * pxe partition image deploy fails in UEFI boot mode
  * Updated from global requirements
  * Fix common misspellings
  * Ilo drivers sets capabilities:boot_mode in node
  * Fixed nits for secure boot support for iLO Drivers
  * Fix typos in ironic/ironic/drivers/modules
  * fix invalid asserts in tests
  * Fail deploy if root uuid or disk id isn't available
  * Hide new fields via single method
  * Update "Ironic as a standalone service" documentation
  * Secure boot support for agent_ilo driver
  * Secure boot support for iscsi_ilo driver
  * Changes for secure boot support for iLO drivers
  2015.1.0b3
  * follow up patch for ilo capabilities
  * Support agent_ilo driver to perform cleaning
  * Implement cleaning/zapping for the agent driver
  * Add Cleaning Operations for iLO drivers
  * Automate uefi boot iso creation for iscsi_ilo driver
  * Generate keystone_authtoken options in sample config file
  * Use task.spawn_after to maintain lock during cleaning
  * is_whole_disk_image might not exist for previous instances
  * Hide inspection_*_at fields if version < 1.6
  * Address nits in uefi agent iscsi deploy commit
* Thu Mar 19 2015 rsalevsky@suse.com
- Update to version ironic-2015.1.dev249:
  * Disable cleaning by default
  * Suppress urllib3.connection INFO level logging
  * Allow periods (".") in hostnames
  * iscsi_ilo driver do not validate boot_option
  * Sync from oslo.incubator
  * Common changes for secure boot support
  * Add pxe_irmc to the sending IPMI sensor data driver list
  * iLO driver updates node capabilities during inspection
  * iLO implementation for hardware inspection
  * Add uefi support for agent iscsi deploy
  * Enable agent_ilo for uefi-bios switching
  * Fixup log message for discoverd
  * Update unittests and use NamedTemporaryFile
  * Rename _continue_deploy() to pass_deploy_info()
  * Write documentation for hardware inspection
  * Start using in-band inspection
  * Log message is missing a blank space
  * Address comments on cleaning commit
  * IPA: Add support for root device hints
  * Use Mock.patch decorator to handle patching amt management module
  * iscsi_ilo driver to support agent ramdisk
  * Enhance AMT driver documentation, pt 2
  * Implement execute clean steps
  * Add missing exceptions to destroy_node docstrings
  * Force LANGUAGE=en_US in test runs
  * Add validations for root device hints
  * Add localboot support for uefi boot mode
  * ironic port deletion fails even if node is locked by same process
  * Add whole disk image support in iscsi_ilo driver
  * Enhance AMT driver documentation
* Thu Jan 29 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev144:
  * Fix drivers.rst doc format error
  * Adds get_glance_image_properties
  * Fix filter_query in drac/power interface
  * Updated from global requirements
  * Agent driver fails with Swift Multiple Containers
* Wed Jan 28 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev134:
  * Replace DIB installation step from git clone to pip
* Tue Jan 27 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev132:
  * Add a TODO file
  * Updated from global requirements
  * Fix function docstring of _get_boot_iso_object_name()
  * Improve ironic-dbsync help strings
  * Clear locks on conductor startup
  * Allow associate an instance independent of the node power state
* Sun Jan 25 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev120:
  * Use oslo_serialization replace oslo.serialization
* Sat Jan 24 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev118:
  * Remove argparse from requirements
  * Add ipmitool to quickstart guide for Ubuntu
  * Allow operations on DEPLOYFAIL'd nodes
  * DracClient to handle ReturnValue validation
* Thu Jan 22 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev111:
  * Improve docstrings about TaskManager's spawning feature
  * Fix instance_info parameters clearing
  * DRAC: Fix wsman host verification
  * Updated from global requirements
  * Clean up ilo's parse_driver_info()
  * Distinguish between prepare + deploy errors
* Wed Jan 21 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev100:
  * Fix ssh _get_power_status as it returned status for wrong node
  * Fix RPCService and Ironic Conductor so they shut down gracefully
  * Remove jsonutils from openstack.common
  * Remove lockfile from dependencies
  * Remove unused state transitions
* Tue Jan 20 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev90:
  * Remove IloPXEDeploy.validate()
  * iboot power driver: unbound variable error
  * DracClient to handle ClientOptions creation
* Sat Jan 17 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev84:
  * Force glance recheck for kernel/ramdisk on rebuild
  * PXE: Add configdrive support
  * Rename localrc for local.conf
  * Ensure we don't have stale power state in database after power action
  * improve the neutron configuration in install-guide
* Fri Jan 16 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev76:
  * Remove links autogenerated from module names
  * Make DD block size adjustable
  * Improve testing of state transitions
  * Convert drivers to use process_event()
  * Update service.py to support graceful Service shutdown
  * Ensure that image link points to the correct image
  * Make 'method' explicit for VendorInterface.validate()
  * Add state machine to documentation
* Thu Jan 15 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev60:
  * Raise SSH failure messages to the error level
  * Updated from global requirements
  * Provided backward compat for enforcing admin policy
  * Allow configuration of neutronclient retries
  * Convert check_deploy_timeout to use process_event
  * Add requests to requirements.txt
  * Enable async callbacks from task.process_event()
  * Document dependency on `fuser` for pxe driver
  * Avoid querying the power state twice
  * Updated from global requirements
* Tue Jan 13 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev40:
  * Adjust the help strings to better reflect usage
  * Updated from global requirements
  * Delete unnecessary document files
* Sun Jan 11 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev34:
  * Fix policy enforcement to properly detect admin
* Sat Jan 10 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev32:
  * Updated from global requirements
  * Update etc/ironic/ironic.conf.sample
  * Minor changes to state model
* Fri Jan  9 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev28:
  * Add documentation to create in RegionOne
  * Updated from global requirements
  * display error logging should be improved
* Thu Jan  8 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev22:
  * Refactor async helper methods in conductor/manager.py
  * Hide oslo.messaging DEBUG logs by default
  * PXE: Pass root device hints via kernel cmdline
  * Add a fsm state -> dot diagram generator
* Tue Jan  6 2015 cloud-devel@suse.de
- Update to version ironic-2015.1.dev15:
  * add comments for NodeStates fields
  * Stop conductor if no drivers were loaded
  * Fix typo in install-guide.rst
  * Use get_my_ipv4 from oslo.utils
  * Refactoring for Ironic policy
* Wed Dec 24 2014 cloud-devel@suse.de
- Update to version ironic-2015.1.dev5:
  * Reuse methods from netutils
* Sat Dec 20 2014 cloud-devel@suse.de
- Update to version ironic-2015.1.dev4:
  * Extend API multivalue fields
* Fri Dec 19 2014 cloud-devel@suse.de
- Update to version ironic-2015.1.dev3:
  * Updated from global requirements
  * Update command options in the Installation Guide
  2015.1.0b1
  * Improve Agent deploy driver validation
* Wed Dec 17 2014 cloud-devel@suse.de
- Update to version ironic-2015.1.dev217.gd98ce6c:
  * Add new enrollment and troubleshooting doc sections
  * Begin using the state machine for node deploy/teardown
  * Add base state machine
* Tue Dec 16 2014 cloud-devel@suse.de
- Update to version ironic-2015.1.dev213.g5aa4f31:
  * Updated from global requirements
  * Remove Python 2.6 from setup.cfg
  * rename oslo.concurrency to oslo_concurrency
* Sun Dec 14 2014 cloud-devel@suse.de
- Update to version ironic-2015.1.dev207.g8067014:
  * Get rid of set_failed_state duplication
  * Correct vmware ssh power manager
* Fri Dec 12 2014 cloud-devel@suse.de
- Update to version ironic-2015.1.dev204.g981b4de:
  * Updated from global requirements
  * Do not strip 'glance://' prefix from image hrefs
  * Use Literal Blocks to write code sample in docstring
* Thu Dec 11 2014 cloud-devel@suse.de
- Update to version ironic-2015.1.dev198.gb9cb080:
  * Update dev quick-start for devstack
  * Updated from global requirements
  * Remove duplicate dependencies from dev-quickstart docs
  * Updated from global requirements
  * Fix image_info passed to IPA for image download
  * Workflow documentation is now in infra-manual
  * Add tests to iscsi_deploy.build_deploy_ramdisk_options
  * Fix for broken deploy of iscsi_ilo driver
  * Updated from global requirements
  * Add info on creating a tftp map file
  * Add documentation for SeaMicro driver
  * Fixed typo in Drac management driver test
  * boot_devices.PXE value should match with pyghmi define
  * Add decorator that requires a lock for Drac management driver
  * Remove useless deprecation warning for node-update maintenance
  * Ilo tests refactoring
  * Change some exceptions from invalid to missing
  * Add decorator that requires a lock for Drac power driver
  * Change methods from classmethod to staticmethod
  * iLO Management Interface
  * Improve docs for running IPA in Devstack
  * Update 'Introduction to Ironic' document
  * Avoid calling _parse_driver_info in every test
  * Updated from global requirements
  * Correct link in user guide
  * Minor fix to install guide for associating k&r to nodes
  * Add serial console feature to seamicro driver
  * Support configdrive in agent driver
  * Add driver_validate()
* Thu Nov 20 2014 tbechtold@suse.com
- Update to version ironic-2015.1.dev147.g9aebde3:
  * Update drivers VendorInterface validate() method
  * Adds help for installing prerequisites on RHEL
  * Add documentation about Vendor Methods
  * Make vendor methods discoverable via the Ironic API
  * Fix PXEDeploy class docstring
  * Updated from global requirements
  * Vendor endpoints to support different HTTP methods
  * Add ipmitool as dependency on RHEL/Fedora systems
  * dev-quickstart.rst update to add required packages
  * Add gendocs tox job for generating the documentation
  * Add gettext to packages needed in dev quickstart
  * Convert qcow2 image to raw format when deploy
  * Update iLO driver documentation
  * Disable IPMI timeout before setting boot device
  * Updated from global requirements
  * ConductorManager catches Exceptions
  * Remove unused variable in agent._get_interfaces()
  * Enable hacking rule E265
  * Add sync and async support for passthru methods
  * Fix documentation on Standard driver interfaces
  * Add a mechanism to route vendor methods
  * Remove redundant FunctionalTest usage in API tests
  * Use wsme.Unset as default value for API objects
  * Fix traceback on rare agent error case
  * Make _send_sensor_data more cooperative
  * Updated from global requirements
  * Add logging to driver vendor_passthru functions
  * Support ipxe with Dnsmasq
  * Correct "returns" line in PXE deploy method
  * Remove all redundant setUp() methods
* Thu Oct  9 2014 cloud-devel@suse.de
- Update to version ironic-2015.1.dev26.g0a0fa0e:
  * Fix pep8 test
  * Add missing attributes to sample API objects
  * Fix markup-related issues in documentation
  * Add documentation for PXE UEFI setup
  * Fix exceptions names and messages for Keystone errors
  * Remove unused change_node_maintenance_mode from rpcapi
* Wed Oct  8 2014 cloud-devel@suse.de
- Update to version ironic-2015.1.dev15.g274a963:
  * Imported Translations from Transifex
  * Clear hash ring cache in get_topic_for*
  * Move database fixture to a separate test case
  * KeyError from AgentVendorInterface._heartbeat()
* Tue Oct  7 2014 cloud-devel@suse.de
- Update to version ironic-2015.1.dev8.gaf59e4b:
  * Validate the power interface before deployment
  * Cleans up some Sphinx rST warnings in Ironic
* Sat Oct  4 2014 cloud-devel@suse.de
- Update to version ironic-2015.1.dev5.g0827173:
  * Remove kombu as a dependency for Ironic
  2014.2.rc1
  * Make hash ring mapping be more consistent
  * Open Kilo development
  * ilo* drivers to use only ilo credentials
  * Remove 'incubated' documentation theme
* Fri Oct  3 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev177.g552a927:
  * Add periodic task to rebuild conductor local state
  * Add "affinity" tracking to nodes and conductors
  * Add a call to management.validate(task)
* Thu Oct  2 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev172.g6a42cee:
  * Update hacking version in test requirements
  * Replace custom lazy loading by stevedore
  * Updated from global requirements
  * Use DbTestCase as test base when context needed
* Wed Oct  1 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev166.gbc61cee:
  * Remove useless variable in migration
  * For convention rename the first classmethod parameter to cls
  * Always reset target_power_state in node_power_action
  * Imported Translations from Transifex
  * Stop running check_uptodate in the pep8 testenv
  * Add HashRingManager to wrap hash ring singleton
  * Force the SSH commands to use their default language
  * Refactor PXE clean up tests
* Mon Sep 29 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev151.g8a0923c:
  * Fix typo in agent validation code
  * Conductor changes target_power_state before starting work
  * Updated from global requirements
* Sun Sep 28 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev145.g5e72ff0:
  * Adds openSUSE support for developer documentation
* Fri Sep 26 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev143.ge5536e2:
  * Remove unneeded context initialization in tests
* Fri Sep 26 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev141.g52f77f9:
  * Remove untranslated PO files
* Thu Sep 25 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev139.g94dc448:
  * Update ironic.conf.sample
  * Add parameter to override locale to utils.execute
  * Updated from global requirements
  * Don't reraise Exceptions from agent driver
  * Add documentation for ironic-dbsync command
* Thu Sep 25 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev130.gb71cd3f:
  * Do not return 'id' in REST API error messages
  * Separate the agent driver config from the base localrc config
  * pxe_ilo driver to call iLO set_boot_device
  * Remove redundant context parameter
  * Update docs with new dbsync command
  * Update devstack docs, require Ubuntu 14.04
* Wed Sep 24 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev119.g2a5d91b:
  * Do not use the context parameter on refresh()
  * Pass ipa-driver-name to agent ramdisk
  * Revert "Revert "Search line with awk itself and avoid grep""
* Tue Sep 23 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev114.g4674aef:
  * Do not set the context twice when forming RPC objects
  * Make context mandatory when instantiating a RPC object
  * Neutron DHCP implementation to raise exception if no ports have VIF
  * Do not cache auth token in Neutron DHCP provider
  * Imported Translations from Transifex
  * Updated from global requirements
* Mon Sep 22 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev102.g931eebc:
  * add_node_capability and rm_node_capability unable to save changes to db
  * Handle SNMP exception error.PySnmpError
* Sat Sep 20 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev98.g8576905:
  * Use standard locale in list_partitions
* Fri Sep 19 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev96.g954ad51:
  * node_uuid should not be used to create test port
  * Add unit tests for SNMPClient
  * Check whether specified FS is supported
  * Sync the doc with latest code
* Thu Sep 18 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev88.g45b4ad3:
  * Fix code error in pxe_ilo driver
  * Add a doc note about the vendor_passthru endpoint
  * Import modules for fake IPMINative/iBoot drivers
* Wed Sep 17 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev84.g93c7ccf:
  * Allow clean_up with missing image ref
  * mock.called_once_with() is not a valid method
  * Fix Devstack docs for zsh users
  * Update ironic states and documentation
  * Stop using intersphinx
* Tue Sep 16 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev75.gf92071e:
  * Fix timestamp column migration
  * Updated from global requirements
  * Don't write python bytecode while testing
* Sat Sep 13 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev71.ga1505ec:
  * Remove the objectify decorator
  * Add reserve() and release() to Node object
  * Add uefi boot mode support in IloVirtualMediaIscsiDeploy
  * Support for setting boot mode in pxe_ilo driver
  * Remove bypassing of H302 for gettextutils markers
* Fri Sep 12 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev62.g20ef93c:
  * Revert "Search line with awk itself and avoid grep"
  * Search line with awk itself and avoid grep
  * Add list_by_node_id() to Port object
  * Log ERROR power state in node_power_action()
* Thu Sep 11 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev55.g8fdd7d0:
  * Remove unused modules from openstack-common.conf
  * Sync the document with the current implementation
  * Unify the sensor data format
  * Updated from global requirements
  * Deprecate Ironic compute driver and sched manager
  * Fix compute_driver and scheduler_host_manager in install-guide
  * Translator functions cleanup part 3
  * Translator functions cleanup part 4
* Wed Sep 10 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev39.g7db8d02:
  * Use oslo.utils instead of ironic.openstack.common
  * Use expected, actual order for PXE template test
  * Fix agent PXE template
  * Translator functions cleanup part 2
  * Imported Translations from Transifex
  * Updated from global requirements
  * Remove XML from api doc samples
  * Update ironic.conf.sample
  * Fix race conditions running pxe_utils tests in parallel
  * Switch to "incubating" doc theme
  * Minor fixes for ipminative console support
  * Translator functions cleanup part 1
  * Remove unnecessary mapping from Agent drivers
  * mock.assert_called_once() is not valid method
  * Use models.TimestampMixin from oslo.db
  * Updated from global requirements
  * Driver merge review comments from 111425
  * Unbreak debugging via testr
* Fri Sep  5 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev4.g823bd59:
  2014.2.b3
  * Nova review updates for _node_resource
  * Ignore backup files
  * IloVirtualMediaAgent deploy driver
  * IloVirtualMediaIscsi deploy driver
  * Interactive console support for ipminative driver
* Thu Sep  4 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev216.g1773bcd:
  * Add UEFI based deployment support in Ironic
  * Adds SNMP power driver
  * Control extra space for images conversion in image_cache
  * Use metadata.create_all() to initialise DB schema
  * Fix minor issues in the DRAC driver
  * Add send-data-to-ceilometer support for pxe_ipminative driver
  * Reduce redundancy in conductor manager docstrings
  * Fix typo in PXE driver docstrings
* Wed Sep  3 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev201.g400b9e5:
  * Update installation guide for syslinux 6
  * Imported Translations from Transifex
  * Avoid deadlock when logging network_info
  * Implements the DRAC ManagementInterface for get/set boot device
  * Add boot_device support for vbox
  * Check ERROR state from driver in _do_sync_power_state
* Tue Sep  2 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev189.g936d263:
  * Updated from global requirements
  * Remove gettextutils _ injection
* Tue Sep  2 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev186.g81344cc:
  * Rewrite images tests with mock
  * Remove futures from requirements
* Mon Sep  1 2014 tbechtold@suse.com
- Update to version ironic-2014.2.dev182.g49877f6:
  * Make DHCP provider pluggable
  * DRAC wsman_{enumerate, invoke}() to return an ElementTree object
  * Script to migrate Nova BM data to Ironic
  * Updated from global requirements
  * Fix unit tests with keystoneclient master
* Fri Aug 29 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev173.g4822e72:
  * Imported Translations from Transifex
  * Add support for interacting with swift
  * Update API document with BootDevice
* Thu Aug 28 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev167.g2a19ff1:
  * properly format user guide in RST
* Thu Aug 28 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev165.g574ea62:
  * Updated from global requirements
  * Fix typo in user-guide.rst
  * Add console interface to agent_ipmitool driver
* Wed Aug 27 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev160.g357081e:
  * Add support for creating vfat and iso images
  * Set PYTHONHASHSEED for venv tox environment
  * Add management interface for agent drivers
  * Add driver name on driver load exception
  * Take iSCSI deploy out of pxe driver
  * Set ssh_virt_type to vmware
  * handle invalid seamicro_api_version
* Tue Aug 26 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev146.gac581d8:
  * Add iPXE Installation Guide documentation
  * Update nova driver's power_off() parameters
* Mon Aug 25 2014 tbechtold@suse.com
- Update to version ironic-2014.2.dev142.g55024af:
  * return power state ERROR instead of an exception
  * Imported Translations from Transifex
  * Nova ironic driver review update requests to p4
  * Allow rebuild of node in ERROR and DEPLOYFAIL state
  * Use cache in node_is_available()
  * Query full node details and cache
  * Add in text for text mode on trusty
  * Add Parallels virtualisation type
  * IPMI double bridging functionality
  * Add DracDriver and its DracPower module
  * use MissingParameterValue exception in iboot
  * Update compute driver macs_for_instance per docs
  * Update DevStack guide when querying the image UUID
  * Updated from global requirements
  * Fix py3k-unsafe code in test_get_properties()
  * Fix tear_down a node with missing info
  * Remove d_info param from _destroy_images
  * Add docs for agent driver with devstack
  * Removes get_port_by_vif
  * Replace incomplete "ilo" driver with pxe_ilo and fake_ilo
  * Handle all exceptions from _exec_ipmitool
  * Remove objectify decorator from dbapi's {get, register}_conductor()
  * Improve exception handling in console code
  * Use valid exception in start_shellinabox_console
  * Remove objectify decorator from dbapi.update_* methods
  * Add list() to Chassis, Node, Port objects
  * Raise MissingParameterValue when validating glance info
  * Mechanism to cleanup all ImageCaches
  * Driver merge review comments from 111425-2-3
  * Raise MissingParameterValue instead of Invalid
* Fri Aug  1 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev37.g0603f74:
  * Remove dbapi calls from agent driver
  * Fix not attribute '_periodic_last_run'
  * Implements send-data-to-ceilometer
  * Updated from global requirements
* Thu Jul 31 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev29.g7f8fed7:
  * Port iBoot PDU driver from Nova
  * Log exception with translation
  * Add ironic-python-agent deploy driver
  * Clean up calls to get_port()
  * Clean up calls to get_chassis()
* Wed Jul 30 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev20.gd0a6893:
  * Imported Translations from Transifex
* Tue Jul 29 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev19.g0b3fbb6:
  * Do not rely on hash ordering in tests
* Tue Jul 29 2014 dmueller@suse.com
- Update to version ironic-2014.2.dev17.g7cb4f6c:
  * Update_port should expect MACAlreadyExists
  * Imported Translations from Transifex
  * Adding swift temp url support
  * Push the image cache ttl way up
  * Imported Translations from Transifex
  * SSH virsh to use the new ManagementInterface
  * Split test case in ironic.tests.conductor.test_manager
  * Tune down node_locked_retry_{attempts,interval} config for tests
  * Add RPC version to test_get_driver_properties
  2014.2.b2
  * Import fixes from the Nova driver reviews
  * Generalize exception handling in Nova driver
  * Fix nodes left in an incosistent state if no workers
  * IPMINative to use the new ManagementInterface
  * Backporting nova host manager changes into ironic
  * Catch oslo.db error instead of sqlalchemy error
  * Add a test case for DB schema comparison
  * remove ironic-manage-ipmi.filters
  * Implement API to get driver properties
  * Add drivers.base.BaseDriver.get_properties()
  * Implement retry on NodeLocked exceptions
  * SeaMicro to use the new ManagementInterface
  * Import fixes from Nova scheduler reviews
  * Rename/update common/tftp.py to common/pxe_utils.py
  * Imported Translations from Transifex
  * Factor out deploy info from PXE driver
  * IPMITool to use the new ManagementInterface
* Wed Jul 16 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev154.ga696fe7:
  * Import a few more fixes from the Nova driver
  * Set a more generous default image cache size
  * Fix wrong test fixture for Node.properties
  * Make ComputeCapabilitiesFilter work with Ironic
  * Add more INFO logging to ironic/common/service.py
  * Update webapi doc with link and console
  * REST API 'limit' parameter to only accept positive values
  * Update docstring for api...node.validate
  * Document 'POST /v1/.../vendor_passthru'
  * Updates Ironic Guide with deployment information
  * Prevent updating UUID of Node, Port and Chassis on DB API level
* Sun Jul 13 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev133.g02f5515:
  * Clean up nova virt driver test code
  * Imported Translations from Transifex
* Sat Jul 12 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev129.gbaf332a:
  * Fix node to chassis and port to node association
* Thu Jul 10 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev127.gd04f6ad:
  * Allow overriding the log level for ironicclient
* Tue Jul  8 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev125.g260a44f:
  * Updated from global requirements
  * Add more INFO logging to ironic/conductor
  * Specify rootfstype=ramfs deploy kernel parameter
  * Add set_spawn_error_hook to TaskManager
* Mon Jul  7 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev118.g95ef3c0:
  * Imported Translations from Transifex
  * Updates the Ironic on Devstack dev documentation
  * Simplify error handling
* Fri Jul  4 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev113.g9ba13b8:
  * Add gettextutils._L* to import_exceptions
  * Fix workaround for the "device is busy" problem
  * Allow noauth for Neutron
  * Minor cleanups to nova virt driver and tests
  * Update nova rebuild to account for new image
* Thu Jul  3 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev103.g510b967:
  * Updated from global requirements
  * pep8 cleanup of Nova code
  * PEP fixes for the Nova driver
  * Update Nova's available resources at termination
  * Fix the section name in CONTRIBUTING.rst
  * Add/Update docstrings in the Nova Ironic Driver
  * Update Nova Ironic Driver destroy() method
  * Nova Ironic driver get_info() to return memory stats in KBytes
  * Add the remaining unittests to the ClientWrapper class
* Wed Jul  2 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev85.gdac09ad:
  * Fix glance endpoint tests
* Sun Jun 29 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev84.g0bbb64d:
  * Wait for Neutron port updates when using SSHPower
* Sat Jun 28 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev82.gbdcfac5:
  * Update "Exercising the Services Locally" doc
* Fri Jun 27 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev80.gdbd96f3:
  * Fix 'fake' driver unable to finish a deploy
* Fri Jun 27 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev79.gfa9a0d0:
  * Fixing hardcoded glance protocol
* Thu Jun 26 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev78.g67adf3c:
  * Remove from_chassis/from_nodes from the API doc
  * Imported Translations from Transifex
  * Do not delete pxe_deploy_{kernel, ramdisk} on tear down
  * Implement security groups and firewall filtering methods
  * Add genconfig tox job for sample config file generation
  * Mock pyghmi lib in unit tests if not present
  * Add some real-world testing on DiskPartitioner
  * Eliminate races in Conductor _check_deploy_timeouts
* Wed Jun 25 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev63.ge34987a:
  * PXE to pass hints to ImageCache on how much space to reclaim
  * Use temporary dir for image conversion
  * Updated from global requirements
  * Move PXE instance level parameters to instance_info
  * Clarify doc: API is admin only
  * Mock time.sleep for the IPMI tests
  * Destroy instance to clear node state on failure
  * Add 'context' parameter to get_console_output()
  * Cleanup virt driver tests and verify final spawn
  * Test fake console driver
  * Virt driver logging improvements
  * ipmitool driver raises DriverLoadError
  * Fix utils.execute() for consistency with Oslo code
  * Fix host manager node detection logic
  * Add missing stats to IronicNodeState
  * Update IronicHostManager tests to better match how code works
  * Improving unit tests for _do_sync_power_state
* Tue Jun 17 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev31.g7a802ca:
  * Enforce a minimum time between all IPMI commands
  * Replace mknod() with chmod()
  * Use .png instead of .gif images
* Mon Jun 16 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev25.gebca58d:
  * VendorPassthru.validate()s call _parse_driver_info
  * Remove 'node' parameter from the validate() methods
  * Test for membership should be 'not in'
  * Factoring out PXE and TFTP functions
  * Let ipmitool natively retry commands
  * Driver interface's validate should return nothing
  * Reuse validate_instance_and_node() Nova ironic Driver
* Fri Jun 13 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev11.g3a2582a:
  * Sync processutils from oslo code
  * Add unique constraint to instance_uuid
* Thu Jun 12 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev8.gfb7817a:
  * remove default=None for config options
  2014.2.b1
  * Stop ipmitool.validate from touching the BMC
  * Set instance default_ephemeral_device
  * Wipe any metadata from a nodes disk
* Thu Jun 12 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev261.gfc56b93:
  * Add node id to DEBUG messages in impitool
  * Remove 'node' parameter from the Console and Rescue interfaces
  * TaskManager: Only support single node locking
  * Add retry logic to iscsiadm commands
  * Remove 'fake' and 'ssh' drivers from default enabled list
  * Mock seamicroclient lib in unit tests if not present
  * Skip migrations test_walk_versions instead of pass
* Wed Jun 11 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev247.gbe25434:
  * Allow more time for API requests to be completed
  * Rework make_partitions logic when preserve_ephemeral is set
  * Update Nova driver's list_instance_uuids()
  * Work around iscsiadm delete failures
  * Cleanup mock patch without `with` part 2
  * Add __init__.py for nova scheduler filters
  * Fix AttributeError when calling create_engine()
  * Fix the logging message to identify node by uuid
  * Fix concurrent deletes in virt driver
  * Log exceptions from deploy and tear_down
  * PXE driver to validate the requested image in Glance
  * Return the HTTP Location for accepted requestes
  * Return the HTTP Location for newly created resources
* Fri May 30 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev223.g63c1030:
  * Fix tests with new keystoneclient
  * list_instances() to return a list of instances names
  * Pass kwargs to ClientWrapper's call() method
  * Remove "node" parameter from methods handling power state in docs
* Thu May 29 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev216.gc4b236b:
  * Remove 'node' parameter from the Power interface
  * Set the correct target versions for the RPC methods
  * Change NodeLocked status code to a client-side error
  * Synced jsonutils from oslo-incubator
  * Implement the reboot command on the Ironic Driver
* Wed May 28 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev207.g286f52c:
  * Consider free disk space before downloading images into cache
  * Add parallel_image_downloads option
  * Fix chassis bookmark link url
  * Run keepalive in a dedicated thread
* Mon May 26 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev200.gec6a73b:
  * Remove 'node' parameter from the Deploy interface
* Mon May 26 2014 dmueller@suse.com
- buildrequire python-ironic to have the correct list of buildrequires
* Fri May 23 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev199.gd5afee9:
  * Imported Translations from Transifex
  * Cleanup images after deployment
* Thu May 22 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev195.ge13ea8b:
  * Remove all mostly untranslated PO files
  * Fix wrong usage of mock methods
  * Using system call for downloading files
  * Renaming ironicclient exceptions in nova driver
* Thu May 22 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev188.g384f09c:
  * Don't translate debug level logs
  * Update dev quickstart guide for ephemeral testing
  * Speed up Nova Ironic driver tests
  * Fix bad Mock calls to assert_called_once()
  * Remove non-existent 'pxe_default_format' parameter from patcher
  * Remove explicit dependency on amqplib
  * Fix 'pxe_preserve_ephemeral' parameter leakage
  * Virt driver change to use API retry config value
* Thu May 15 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev173.g6239eb8:
  * Updated from global requirements
* Wed May 14 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev171.gb7d916a:
  * Cleanup mock patch without `with` part 1
* Tue May 13 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev170.g0acc05f:
  * Corrects a typo in RESTful Web API (v1) document
  * Clean up openstack-common.conf
  * Check requested image size
* Fri May  9 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev164.g70646b4:
  * Pin RPC client version min == max
  * Simplify calls to ImageCache in PXE module
* Wed May  7 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev161.g5df5032:
  * RPC_API_VERSION out of sync
  * Place root partition last so that it can always be expanded
  * Stop creating a swap partition when none was specified
* Tue May  6 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev156.gf587d47:
  * Implement more robust caching for master images
  * Decouple state inspection and availability check
  * Fix ironic node state comparison
  * Support serial console access
* Tue May  6 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev148.g5701b43:
  * Updated from global requirements
  * Add create() and destroy() to Node
  * Implement instance rebuild in nova.virt.driver
* Fri May  2 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev143.g56e8424:
  * Fix typo in rpcapi.driver_vendor_passthru
  * Remove 'node' parameter from the VendorPassthru interface
  * Fix chassis-node relationship
  * Return error immediately if set_console_mode is not supported
* Thu May  1 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev136.gacd0ad5:
  * Updated from global requirements
  * Synced jsonutils from oslo-incubator
  * Add ManagementInterface
* Wed Apr 30 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev132.gc149efd:
  * Sync oslo logging
  * Clean oslo dependencies files
  * Fix bypassed reference to node state values
  * Overwrite instance_exists in Nova Ironic Driver
  * Document ClusteredComputeManager
* Mon Apr 28 2014 dmueller@suse.com
- Update to version ironic-2014.2.dev122.gd36e3de:
  * Updated from global requirements
  * Port to oslo.messaging
  * Update Ironic User Guide post landing for 41af7d6b
  * Remove hardcoded node id value
* Sat Apr 26 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev114.g8acd323:
  * Drivers may expose a top-level passthru API
  * Spawn support for TaskManager and 2 locking fixes
  * Clean up calls to get_node()
  * nova.virt.ironic passes ephemeral_gb to ironic
  * Sync oslo/common/excutils
* Wed Apr 23 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev104.g6ef3be1:
  * Implement list_instance_uuids() in Nova driver
  * Modify the get console API
  * Add worker threads limit to _check_deploy_timeouts task
  * cleanup docstring for drivers.utils.get_node_mac_addresses
* Sat Apr 19 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev96.g2291251:
  * Complete wrapping ironic client calls
* Fri Apr 18 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev95.g9ff949c:
  * Use DiskPartitioner
* Thu Apr 17 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev93.g6dd05db:
  * Better handling of missing drivers
  * Update ironic.conf.sample
  * Make sync_power_states yield
  * Refactor sync_power_states tests to not use DB
  * Add DiskPartitioner
* Thu Apr 17 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev85.g36041ad:
  * Some minor clean up of various doc pages
  * Fix message preventing overwrite the instance_uuid
* Wed Apr 16 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev81.g2c61333:
  * Install guide for Ironic
  * Refactor the driver fields mapping
  * Imported Translations from Transifex
  * Fix conductor.manager test assertion order
  * Overwriting node_is_available in IronicDriver
  * Sync oslo/config/generator
  * Add Ironic User Guide
  * Remove a DB query for get_ports_by_node()
  * Encapsulate Ironic client retry logic
* Tue Apr 15 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev64.gb1e971c:
  * Cherry pick oslo rpc HA fixes
  * Fix missed stopping of conductor service
* Sat Apr 12 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev62.g6ead43f:
  * Do not sync power state for new invalidated nodes
  * Make tests use Node object instead of dict
  * Sync object list stuff from Nova
  * Fix Node object version
  * Cleanup running conductor services in tests
  * Factor hash ring management out of the conductor
  * Updated from global requirements
  * Remove usage of Glance from PXE clean_up()
  * Supports filtering port by address
  * Move duplicated _get_node(s)_mac_addresses()
* Thu Apr 10 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev42.g2eb641a:
  * Replace sfdisk with parted
  * Handling validation in conductor consistently
  * Fix hosts mapping for conductor's periodic tasks
  * Fix Nova rescheduling tear down problem
* Wed Apr  9 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev34.gde352b9:
  * JsonPatch add operation on existing property
  * Fix seamicro power.validate() method definition
  * Sync base object code with Nova's
  * Fix self.fields on API Node object
* Tue Apr  8 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev27.g322d3b4:
  * Update tox.ini to also run nova tests
  * Use xargs -0 instead of --null
  * Add Node.instance_info field
  * Show maintenance field in GET /nodes
* Sat Apr  5 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev19.g32b24fa:
  * Updated from global requirements
  * Fix messages formatting for _sync_power_states
  * Refactor nova.virt.ironic.driver get_host_stats
  * Change admin_url help in ironic driver
  * Reduce logging output from non-Ironic libraries
* Fri Apr  4 2014 cloud-devel@suse.de
- Update to version ironic-2014.2.dev9.gbb582f0:
  * Fix grammar in error string in pxe driver
* Thu Apr  3 2014 dmueller@suse.com
- Update to version ironic-2014.2.dev7.g5f9dad2:
  * Open Juno development
  2014.1.rc1
  * Fix spelling error in conductor/manager
  * Improved coverage for ironic API
  * Manually update all translated strings
  * Check that all po/pot files are valid
  * If no swap is specified default to 1MB
  * Remove obsolete po entries - they break translation jobs
  * Add note to ssh about impact on ci testing
  * Adds exact match filters to nova scheduler
  * Clean up IronicNodeStates.update_from_compute_node
  * ironic_host_manager was missing two stats
  * Imported Translations from Transifex
  * Fix seamicro validate() method definition
  * Remove some obsolete settings from DevStack doc
  * Raise unexpected exceptions during destroy()
  * Start using oslosphinx theme for docs
  * Provide a new ComputeManager for Ironic
  * Nova Ironic driver to set pxe_swap_mb in Ironic
  * Fix strings post landing for c63e1d9f6
  * Run periodic_task in a with a dynamic timer
  * Update SeaMicro to use MixinVendorInterface
  * Run ipmi power status less aggressively
  * Avoid API root controller dependency on v1 dir
  * Update Neutron if mac address of the port changed
  * Replace fixtures with mock in test_keystone.py
  * Decrease running time of SeaMicro driver tests
* Tue Mar 25 2014 cloud-devel@suse.de
- Update to version ironic-2014.1.dev104.g809cbf9:
  * Pass no arguments to _wait_for_provision_state()
  * Imported Translations from Transifex
  * Stop incorrectly returning rescue: supported
  * Correct version.py and update current version string
  * Hide rescue interface from validate() output
  * Change JsonEncodedType.impl to TEXT
  * Fix traceback hook for avoid duplicate traces
  * Permit passing SSH keys into the Ironic API
* Sat Mar 22 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev88.g17e614e:
  * Documentation for deploying DevStack /w Ironic
  * Change set_console_mode(
  * Fix help string for a glance option
  * Better instance-not-found handling within IronicDriver
  * Conductor de-registers on shutdown
* Fri Mar 21 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev79.gf602116:
  * Expose API for fetching a single driver
* Wed Mar 19 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev78.g021c6bd:
  * Make sure auth_url exists and is not versionless
  * Change deploy validation exception handling
  * PXE validate() to fail if no Ironic API URL
* Tue Mar 18 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev72.g1e0760d:
  * Suppress conductor logging of expected exceptions
  * Remove unused method from timeutils
  * Add admin_auth_token option for nova driver
  * Stop logging paramiko's DEBUG and INFO messages
  * Delete node while waiting for deploy
* Sat Mar 15 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev62.ga8fb7b7:
  * Remove redundant nova virt driver test
  * Enable pep8 tests for the Nova Ironic Driver
  * Fix typo tenet -> tenant
* Fri Mar 14 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev57.g9e15b9c:
  * Set boot device to PXE when deploying
  * Driver utils should raise unsupported method
  * Check BMC availability in ipmitool 'validate' method
  * SeaMicro use device parameter for set_boot_device
  * Make the Nova Ironic driver to wait for ACTIVE
  * Fix misspelled impi to ipmi
  * Use range instead xrange to keep python 3.X compatibility
  * Set the database.connection option default value
* Thu Mar 13 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev41.g287fe84:
  * Improve Ironic Conductor threading & locks
  * Mark hash_replicas as experimental
* Wed Mar 12 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev38.g5405dd1:
  * Generic MixinVendorInterface using static mapping
  * Conductor logs better error if seamicroclient missing
  * Add TaskManager lock on change port data
* Tue Mar 11 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev33.g1f8b8d7:
  * Nova ironic driver to retry on HTTP 503
  * Move v1 API tests to separate v1 directory
* Mon Mar 10 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev30.g81b0c94:
  * do_node_deploy() to use greenthreads
  * Pin iso8601 logging to WARN
  * Only fetch node once for vif actions
  * Fix how nova ironic driver gets flavor information
  * Imported Translations from Transifex
  * API: Add sample() method to remaining models
  * Import Nova "ironic" driver
  * Remove errors from API documentation
  * Add libffi-dev(el) dependency to quickstart
  * Updated from global requirements
  * Remove redundant default value None for dict.get
  2014.1.b3
  * Refactor vendor_passthru to use conductor async workers
  * Remove jsonutils from test_rpcapi
  * Sync common db code from Oslo
* Thu Mar  6 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev246.g3e03681:
  * PXE clean_up() to remove the pxe_deploy_key parameter
* Thu Mar  6 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev244.g9654a4e:
  * Sync the log_handler from oslo
  * Fix SeaMicro driver post landing for ba207b4aa0
* Wed Mar  5 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev240.ge52d6af:
  * Fix wrong exception raised by conductor for node
  * Fix params order in assertEqual
  * Implements SeaMicro VendorPassThru functionality
  * Do not delete a Node which is not powered off
  * Python 3: replace "im_self" by "__self__"
* Tue Mar  4 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev231.gcc62836:
  * Implement the SeaMicro Power driver
  * Fix provision_updated_at deserialization
* Sun Mar  2 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev228.g76e6305:
  * Add provision_updated_at to node's resource
  * Prevent a node in maintenance from being deployed
  * Updated from global requirements
* Sat Mar  1 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev222.g7535d2f:
  * Allow clients to mark a node as in maintenance
  * Support preserve_ephemeral
  * API: Expose a way to start/stop the console
  * Add option to sync node power state from DB
  * Make the PXE driver understand ephemeral disks
  * Log deploy_utils.deploy() erros in the PXE driver
  * Removing get_node_power_state, bumping RPC version
  * Add timeout for waiting callback from deploy ramdisk
  * Prevent GET /v1/nodes returning maintenance field
  * Suggested improvements to _set_boot_device
  * Move ipminative _set_boot_device to VendorPassthru
  * Add support for custom libvirt uri
  * Remove extraneous vim configuration comments for ironic
  * Do not allow POST ports and chassis internal attributes
  * Do not allow POST node's internal attributes
  * Use six.moves.urllib.parse instead of urlparse
* Thu Feb 27 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev191.gbdd96dc:
  * Fix race condition when deleting a node
* Wed Feb 26 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev190.g1a57ac4:
  * Unused 'pxe_key_data' & 'pxe_instance_name' info
  * Add provision_updated_at field to nodes table
  * Exclude nodes in DEPLOYWAIT state from _sync_power_states
  * Sync common config module from Oslo
  * Get rid object model `dict` methods part 4
  * Sync Oslo rpc module to Ironic
  * Clarify and fix the dev-quickstart doc some more
  * Do not use CONF as a default parameter value
  * Simplify locking around acquiring Node resources
  * Improve help strings
  * Remove shebang lines from code
  * Sync Oslo gettextutils module to Ironic
  * NodeLocked returns 503 error status
  * Sync Oslo service module to Ironic
  * Use six.StringIO/BytesIO instead of StringIO.StringIO
  * Don't raise MySQL 2013 'Lost connection' errors
  * Removes use of timeutils.set_time_override
* Fri Feb 21 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev157.g23b7f53:
  * Add string representation method to MultiType
  * Fix test migrations for alembic
  * Supports OPERATOR priv level for ipmitool driver
* Wed Feb 19 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev152.ga3d65c7:
  * Move ipmitool _set_boot_device to VendorPassthru
* Tue Feb 18 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev150.g6a1c153:
  * Correct assertEqual order from patch e69e41c99fb
  * PXE and SSH validate() method to check for a port
  * Task object as paramater to validate() methods
  * Fix dev-quick-start.rst post landing for 9d81333fd0
  * API validates driver name for both POST and PATCH
  * Add JSONEncodedType with enforced type checking
  * Use the custom wsme BooleanType on the nodes api
  * Add wsme custom BooleanType type
  * Add common.service config options to sample
  * Use StringType from WSME
  * Allow to tear-down a node waiting to be deployed
* Mon Feb 17 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev128.gba3c407:
  * Correct PXEPrivateMethodsTestCase.setUp
  * alembic with initial migration and tests
* Sun Feb 16 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev125.g11968a7:
  * Fix task_manager acquire post landing for c4f2f26ed
  * Make ironic-api not single threaded
  * Move eventlent monkeypatch out of cmd/
* Fri Feb 14 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev120.g106e6e1:
  * Replace assertEqual(None, *) with assertIsNone in tests
  * Replace nonexistent mock assert methods with real ones
  * Log IPMI power on/off timeouts
  * Remove None as default value for dict get()
  * Fix autodoc formatting in pxe.py
  * Fix race condition when changing node states
  * Add testing and doc sections to docs/dev-quickstart
  * Implement _update_neutron in PXE driver
  * Remove _load_one_plugin fallback
  * Remove POST calls in tests for resource creation
  * Add topic to the change_node_maintenance_mode() RPC method
  * Fix API inconsistence when changing node's states
  * Add samples to serve API through Apache mod_wsgi
  * Add get_console() method
  * Remove unnecessary json dumps/loads from tests
  * Updated from global requirements
* Thu Feb 13 2014 cloud-devel@suse.de
- Update to version ironic-2013.2.dev88.gc6c3c8c:
  * SSHPower driver support VMware ESXi
  * Add parameter for filtering nodes by maintenance mode
  * Implement a multiplexed VendorPassthru example
* Wed Feb 12 2014 speilicke@suse.com
- Update to version ironic-2013.2.dev83.g7eb48ad:
  * Add git dependency to quickstart docs
  * Rename and update ironic-deploy-helper rootwrap
  * Remove tox locale overrides
  * Fix misspellings in ironic
  * Ensure parameter order of assertEqual correct
  * Return correct HTTP response codes for create ops
  * Fix broken doc links on the index page
  * Improve NodeLocked exception message
  * Expose 'reservation' field of a node via API
  * Fix log and test for NeutronAPI.update_port_dhcp_opts
  * Fix 'run_as_root' parameter check in utils
  * Handle multiple exceptions raised by jsonpatch
  * API tests to check for the return codes
  * Imported Translations from Transifex
  * Move test__get_nodes_mac_addresses
  * Removed duplicated function to create a swap fs
  * Updated from global requirements
  * Add futures to requirements
  * Fix missing keystone option in ironic.conf.sample
  * Adds Neutron support to Ironic
  * Replace CONF.set_default with self.config
  * Fix ssh_port type in _parse_driver_info() from ssh.py
  * Improve handling of invalid input in HashRing class
  * Sync db.sqlalchemy code from Oslo
  * Add lockfile>=0.8 to requirements.txt
  * Remove net_config_template options
  * Remove deploy kernel and ramdisk global config
  * Update docstrings in ssh.py
* Wed Jan  8 2014 speilicke@suse.com
- Fix requirements
* Tue Jul  9 2013 dmueller@suse.com
- fix build
* Mon Jun 24 2013 dmueller@suse.com
- Initial package
